CREATE TABLE IF NOT EXISTS Scheme(id INTEGER NOT NULL,width FLOAT NOT NULL,height FLOAT NOT NULL,latitude FLOAT NOT NULL,longitude FLOAT NOT NULL,latitudeDelta FLOAT NOT NULL,longitudeDelta FLOAT NOT NULL,initialPositionX FLOAT NOT NULL,initialPositionY FLOAT NOT NULL,country TEXT(4) NOT NULL, version TEXT(8), PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS Line(id INTEGER NOT NULL,line_id INTEGER NOT NULL,color INTEGER NOT NULL,scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS Station(id INTEGER NOT NULL,station_id INTEGER NOT NULL,type TEXT(15) NOT NULL,positionX FLOAT NOT NULL,positionY FLOAT NOT NULL,latitude FLOAT NOT NULL,longitude FLOAT NOT NULL,timeWeight FLOAT NOT NULL DEFAULT(-1),customSchemePositionX FLOAT NOT NULL DEFAULT(-1),customSchemePositionY FLOAT NOT NULL DEFAULT(-1),alignment TEXT(10) NOT NULL,sameAsStation INTEGER NOT NULL,scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,line_id,PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS Link(id INTEGER NOT NULL,time INTEGER NOT NULL DEFAULT(-1),transfer INTEGER NOT NULL DEFAULT(0),scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,from_station_id INTEGER NOT NULL REFERENCES Station(id),to_station_id INTEGER NOT NULL REFERENCES Station(id), PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS DrawElement(id INTEGER NOT NULL,type TEXT NOT NULL,orderIndex INTEGER NOT NULL,x FLOAT NOT NULL,y FLOAT NOT NULL,radius FLOAT NOT NULL,startAngle FLOAT NOT NULL,endAngle FLOAT NOT NULL,link_id INTEGER NOT NULL REFERENCES Link(id),scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS Transfer(id INTEGER NOT NULL,scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS StationForTransfer(id INTEGER NOT NULL,transfer_id INTEGER NOT NULL,station_id INTEGER NOT NULL,orderIndex INTEGER NOT NULL,scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE,PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS String (type SHORT NOT NULL, id INTEGER NOT NULL, lang TEXT(4) NOT NULL, string TEXT(64), scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE);
CREATE TABLE IF NOT EXISTS "History" ("id" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL  UNIQUE  DEFAULT 1, "station_from_id" INTEGER NOT NULL REFERENCES Station(station_id), "station_to_id" INTEGER NOT NULL REFERENCES Station(station_id), scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE, "date_created" DATETIME NOT NULL );
CREATE TABLE IF NOT EXISTS ExitBoardPosition (id INTEGER NOT NULL, station_id INTEGER NOT NULL, prev_station_id INTEGER NOT NULL, board_positions INTEGER NOT NULL, scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE, PRIMARY KEY (id));
CREATE TABLE IF NOT EXISTS TransferBoardPosition (id INTEGER NOT NULL, station_id INTEGER NOT NULL, prev_station_id INTEGER NOT NULL, to_station_id INTEGER NOT NULL, next_station_id INTEGER NOT NULL, board_positions INTEGER NOT NULL, scheme_id INTEGER NOT NULL REFERENCES Scheme(id) ON DELETE CASCADE, PRIMARY KEY (id));
INSERT INTO Scheme VALUES (1, 1000.0, 1000.0, 55.743347, 37.617188, 0.32158, 0.439453, 0.0, 0.0, 'ru', '1.0');
INSERT INTO Scheme VALUES (13, 420.0, 345.0, 53.902313, 27.55371, 0.168291, 0.219727, 50.0, 0.0, 'bel', '1.0');
INSERT INTO Scheme VALUES (2, 780.0, 555.0, 59.95501, 30.333252, 0.286034, 0.439453, 145.0, 0.0, 'ru', '1.0');
INSERT INTO Scheme VALUES (8, 860.0, 400.0, 50.436516, 30.509033, 0.363873, 0.439453, 281.0, 0.0, 'ukr', '1.0');
INSERT INTO Scheme VALUES (9, 530.0, 430.0, 49.97949, 36.271362, 0.367374, 0.439453, 66.0, 0.0, 'ukr', '1.0');
INSERT INTO Line VALUES (0, 1, -1106395, 1);
INSERT INTO Line VALUES (1, 2, -16606635, 1);
INSERT INTO Line VALUES (2, 3, -16624990, 1);
INSERT INTO Line VALUES (3, 4, -16671008, 1);
INSERT INTO Line VALUES (4, 5, -9151441, 1);
INSERT INTO Line VALUES (5, 6, -284109, 1);
INSERT INTO Line VALUES (6, 7, -4842098, 1);
INSERT INTO Line VALUES (7, 8, -10237, 1);
INSERT INTO Line VALUES (8, 9, -5460561, 1);
INSERT INTO Line VALUES (9, 10, -5123278, 1);
INSERT INTO Line VALUES (10, 11, -11497029, 1);
INSERT INTO Line VALUES (11, 12, -8006413, 1);
INSERT INTO Line VALUES (12, 1, -16624990, 13);
INSERT INTO Line VALUES (13, 2, -1106395, 13);
INSERT INTO Line VALUES (14, 1, -1106395, 2);
INSERT INTO Line VALUES (15, 2, -16671008, 2);
INSERT INTO Line VALUES (16, 3, -16606635, 2);
INSERT INTO Line VALUES (17, 4, -284109, 2);
INSERT INTO Line VALUES (18, 5, -4842098, 2);
INSERT INTO Line VALUES (19, 1, -1106395, 8);
INSERT INTO Line VALUES (20, 2, -16624990, 8);
INSERT INTO Line VALUES (21, 3, -16606635, 8);
INSERT INTO Line VALUES (22, 1, -1106395, 9);
INSERT INTO Line VALUES (23, 2, -16624990, 9);
INSERT INTO Line VALUES (24, 3, -16606635, 9);
INSERT INTO Station VALUES (0, 1, 'Station', 730.0, 110.0, 55.8144, 37.734, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (1, 2, 'Station', 730.0, 130.0, 55.803787, 37.74473, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (2, 3, 'Station', 730.0, 150.0, 55.79607, 37.715633, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (3, 4, 'Station', 730.0, 170.0, 55.789253, 37.679737, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (4, 5, 'Station', 730.0, 190.0, 55.779957, 37.665966, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (5, 6, 'Transfer', 660.0, 260.0, 55.774273, 37.65616, 0.0, 670.0, 260.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (6, 7, 'Station', 620.0, 300.0, 55.7688, 37.649117, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (7, 8, 'Transfer', 595.0, 325.0, 55.765663, 37.638702, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (8, 9, 'Transfer', 532.0, 388.0, 55.75929, 37.626884, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (9, 10, 'Transfer', 471.0, 449.0, 55.757378, 37.615936, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (10, 11, 'Transfer', 395.0, 525.0, 55.751583, 37.610058, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (11, 12, 'Station', 370.0, 550.0, 55.745346, 37.603836, 0.0, -1.0, -1.0, 'left', -1, 1, 1);
INSERT INTO Station VALUES (12, 13, 'Transfer', 341.0, 579.0, 55.73551, 37.594395, 0.0, 331.0, 564.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (13, 14, 'Station', 300.0, 620.0, 55.727455, 37.5805, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (14, 15, 'Station', 280.0, 640.0, 55.72305, 37.5638, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (15, 16, 'Station', 260.0, 660.0, 55.71024, 37.559254, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (16, 17, 'Station', 240.0, 680.0, 55.69259, 37.534786, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (17, 18, 'Station', 220.0, 700.0, 55.676666, 37.505608, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (18, 19, 'Station', 200.0, 720.0, 55.663643, 37.483208, 0.0, -1.0, -1.0, 'right', -1, 1, 1);
INSERT INTO Station VALUES (19, 20, 'Station', 335.0, 20.0, 55.85494, 37.47617, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (20, 21, 'Station', 335.0, 40.0, 55.839855, 37.48683, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (21, 22, 'Station', 335.0, 60.0, 55.8185, 37.498055, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (22, 23, 'Station', 335.0, 80.0, 55.80503, 37.515247, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (23, 24, 'Station', 335.0, 100.0, 55.800606, 37.53222, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (24, 25, 'Station', 335.0, 120.0, 55.7897, 37.558224, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (25, 26, 'Station', 395.0, 252.0, 55.777287, 37.5822, 0.0, -1.0, -1.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (26, 27, 'Station', 395.0, 333.0, 55.77027, 37.595646, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (27, 28, 'Transfer', 395.0, 358.0, 55.7646, 37.605686, 0.0, -1.0, -1.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (28, 29, 'Transfer', 471.0, 434.0, 55.757744, 37.618893, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (29, 30, 'Transfer', 558.0, 521.0, 55.742332, 37.629086, 0.0, -1.0, -1.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (30, 31, 'Transfer', 637.0, 600.0, 55.730465, 37.637257, 0.0, 647.0, 585.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (31, 32, 'Station', 665.0, 660.0, 55.707676, 37.657528, 0.0, -1.0, -1.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (32, 33, 'Station', 665.0, 680.0, 55.677876, 37.663708, 0.0, -1.0, -1.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (33, 34, 'Transfer', 665.0, 700.0, 55.65505, 37.64943, 0.0, 655.0, 700.0, 'right', -1, 1, 2);
INSERT INTO Station VALUES (34, 35, 'Station', 665.0, 785.0, 55.63575, 37.656498, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (35, 36, 'Station', 665.0, 805.0, 55.621017, 37.669456, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (36, 37, 'Station', 665.0, 825.0, 55.613407, 37.694523, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (37, 38, 'Station', 665.0, 845.0, 55.610596, 37.71804, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (38, 39, 'Station', 665.0, 865.0, 55.613796, 37.744473, 0.0, -1.0, -1.0, 'left', -1, 1, 2);
INSERT INTO Station VALUES (39, 40, 'Station', 796.0, 227.0, 55.80953, 37.798634, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (40, 41, 'Station', 796.0, 247.0, 55.794575, 37.79932, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (41, 42, 'Station', 796.0, 267.0, 55.787674, 37.78164, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (42, 43, 'Station', 796.0, 287.0, 55.788498, 37.749603, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (43, 44, 'Station', 796.0, 307.0, 55.783054, 37.719376, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (44, 45, 'Station', 796.0, 327.0, 55.782124, 37.705437, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (45, 46, 'Station', 796.0, 347.0, 55.77235, 37.678787, 0.0, -1.0, -1.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (46, 47, 'Transfer', 714.0, 429.0, 55.75783, 37.65783, 0.0, 724.0, 429.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (47, 48, 'Transfer', 471.0, 464.0, 55.756676, 37.622086, 0.0, 481.0, 457.0, 'left', -1, 1, 3);
INSERT INTO Station VALUES (48, 49, 'Transfer', 395.0, 510.0, 55.752285, 37.604664, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (49, 50, 'Station', 335.0, 450.0, 55.747894, 37.58357, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (50, 51, 'Transfer', 287.0, 402.0, 55.743034, 37.564976, 0.0, 277.0, 380.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (51, 52, 'Station', 132.0, 295.0, 55.736244, 37.51702, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (52, 53, 'Station', 132.0, 275.0, 55.729816, 37.47205, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (53, 54, 'Transfer', 132.0, 170.0, 55.730667, 37.44544, 0.0, 122.0, 155.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (54, 55, 'Station', 132.0, 120.0, 55.740738, 37.41686, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (55, 56, 'Station', 132.0, 100.0, 55.75673, 37.408104, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (56, 57, 'Station', 132.0, 80.0, 55.80374, 37.4027, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (57, 178, 'Station', 132.0, 60.0, 55.823593, 37.385178, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (58, 179, 'Station', 132.0, 40.0, 55.83553, 37.382397, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (59, 180, 'Station', 132.0, 20.0, 55.846146, 37.36198, 0.0, -1.0, -1.0, 'right', -1, 1, 3);
INSERT INTO Station VALUES (60, 58, 'Transfer', 132.0, 155.0, 55.730667, 37.446533, 0.0, -1.0, -1.0, 'none', 54, 1, 4);
INSERT INTO Station VALUES (61, 59, 'Station', 172.0, 195.0, 55.73599, 37.46715, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (62, 60, 'Station', 172.0, 215.0, 55.739517, 37.483356, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (63, 61, 'Station', 172.0, 235.0, 55.743732, 37.497765, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (64, 62, 'Station', 172.0, 255.0, 55.746002, 37.514877, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (65, 63, 'Station', 172.0, 275.0, 55.739964, 37.53462, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (66, 64, 'Station', 172.0, 295.0, 55.73888, 37.548355, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (67, 65, 'Transfer', 287.0, 372.0, 55.74378, 37.5661, 0.0, -1.0, -1.0, 'none', 51, 1, 4);
INSERT INTO Station VALUES (68, 66, 'Station', 335.0, 420.0, 55.748985, 37.58217, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (69, 67, 'Station', 365.0, 450.0, 55.75212, 37.601555, 0.0, -1.0, -1.0, 'left', -1, 1, 4);
INSERT INTO Station VALUES (70, 68, 'Transfer', 395.0, 480.0, 55.75269, 37.607815, 0.0, -1.0, -1.0, 'right', -1, 1, 4);
INSERT INTO Station VALUES (71, 69, 'Station', 267.0, 352.0, 55.749146, 37.543285, 0.0, -1.0, -1.0, 'right', -1, 1, 4);
INSERT INTO Station VALUES (72, 70, 'Station', 247.0, 332.0, 55.74857, 37.53288, 0.0, -1.0, -1.0, 'right', -1, 1, 4);
INSERT INTO Station VALUES (73, 71, 'Transfer', 341.0, 564.0, 55.73521, 37.592995, 0.0, -1.0, -1.0, 'none', 13, 1, 5);
INSERT INTO Station VALUES (74, 72, 'Transfer', 416.0, 618.0, 55.729256, 37.611553, 0.0, 406.0, 618.0, 'right', -1, 1, 5);
INSERT INTO Station VALUES (75, 73, 'Transfer', 545.0, 630.0, 55.728996, 37.622894, 0.0, -1.0, -1.0, 'left', -1, 1, 5);
INSERT INTO Station VALUES (76, 74, 'Transfer', 637.0, 585.0, 55.730934, 37.635822, 0.0, -1.0, -1.0, 'none', 31, 1, 5);
INSERT INTO Station VALUES (77, 75, 'Transfer', 680.0, 536.0, 55.74237, 37.65361, 0.0, 670.0, 521.0, 'right', -1, 1, 5);
INSERT INTO Station VALUES (78, 76, 'Transfer', 714.0, 444.0, 55.75734, 37.65933, 0.0, -1.0, -1.0, 'none', 47, 1, 5);
INSERT INTO Station VALUES (79, 77, 'Transfer', 660.0, 275.0, 55.775974, 37.65637, 0.0, -1.0, -1.0, 'none', 6, 1, 5);
INSERT INTO Station VALUES (80, 78, 'Transfer', 595.0, 227.0, 55.779648, 37.633533, 0.0, 605.0, 212.0, 'left', -1, 1, 5);
INSERT INTO Station VALUES (81, 79, 'Transfer', 462.0, 208.0, 55.77949, 37.601036, 0.0, -1.0, -1.0, 'right', -1, 1, 5);
INSERT INTO Station VALUES (82, 80, 'Station', 395.0, 232.0, 55.776234, 37.58395, 0.0, -1.0, -1.0, 'right', -1, 1, 5);
INSERT INTO Station VALUES (83, 81, 'Transfer', 328.0, 291.0, 55.76032, 37.576935, 0.0, -1.0, -1.0, 'left', -1, 1, 5);
INSERT INTO Station VALUES (84, 82, 'Transfer', 287.0, 387.0, 55.74447, 37.567356, 0.0, -1.0, -1.0, 'none', 51, 1, 5);
INSERT INTO Station VALUES (85, 83, 'Station', 595.0, 20.0, 55.88701, 37.66139, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (86, 84, 'Station', 595.0, 40.0, 55.86982, 37.664223, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (87, 85, 'Station', 595.0, 60.0, 55.85513, 37.65272, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (88, 86, 'Station', 595.0, 80.0, 55.845448, 37.63839, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (89, 87, 'Station', 595.0, 100.0, 55.82067, 37.640705, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (90, 88, 'Station', 595.0, 120.0, 55.807808, 37.638447, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (91, 89, 'Station', 595.0, 140.0, 55.79248, 37.63583, 0.0, -1.0, -1.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (92, 90, 'Transfer', 595.0, 212.0, 55.7818, 37.633232, 0.0, -1.0, -1.0, 'none', 78, 1, 6);
INSERT INTO Station VALUES (93, 91, 'Station', 595.0, 250.0, 55.772568, 37.632557, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (94, 92, 'Transfer', 595.0, 310.0, 55.766487, 37.637177, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (95, 93, 'Transfer', 595.0, 451.0, 55.756077, 37.63181, 0.0, 605.0, 436.0, 'left', -1, 1, 6);
INSERT INTO Station VALUES (96, 94, 'Transfer', 558.0, 491.0, 55.740765, 37.62511, 0.0, 548.0, 491.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (97, 95, 'Transfer', 416.0, 633.0, 55.731308, 37.612686, 0.0, -1.0, -1.0, 'none', 72, 1, 6);
INSERT INTO Station VALUES (98, 96, 'Station', 383.0, 675.0, 55.718777, 37.60813, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (99, 97, 'Station', 383.0, 695.0, 55.707626, 37.586205, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (100, 98, 'Station', 383.0, 715.0, 55.687744, 37.573414, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (101, 99, 'Station', 383.0, 735.0, 55.677876, 37.56286, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (102, 100, 'Station', 383.0, 755.0, 55.670227, 37.55462, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (103, 101, 'Station', 383.0, 775.0, 55.65653, 37.53994, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (104, 102, 'Station', 383.0, 795.0, 55.64258, 37.526295, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (105, 103, 'Station', 383.0, 815.0, 55.63352, 37.519424, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (106, 104, 'Station', 383.0, 835.0, 55.618835, 37.50707, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (107, 105, 'Station', 383.0, 855.0, 55.60623, 37.53346, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (108, 106, 'Station', 383.0, 875.0, 55.60087, 37.555084, 0.0, -1.0, -1.0, 'right', -1, 1, 6);
INSERT INTO Station VALUES (109, 107, 'Station', 295.0, 20.0, 55.860573, 37.43634, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (110, 108, 'Station', 295.0, 40.0, 55.850216, 37.439945, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (111, 109, 'Station', 295.0, 60.0, 55.82689, 37.43737, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (112, 110, 'Station', 295.0, 80.0, 55.808468, 37.46432, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (113, 111, 'Station', 295.0, 100.0, 55.793465, 37.49342, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (114, 112, 'Station', 295.0, 120.0, 55.77749, 37.51891, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (115, 113, 'Station', 295.0, 140.0, 55.773533, 37.54715, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (116, 114, 'Station', 295.0, 160.0, 55.764694, 37.561398, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (117, 115, 'Transfer', 328.0, 306.0, 55.760666, 37.581295, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (118, 116, 'Transfer', 395.0, 373.0, 55.765636, 37.605083, 0.0, -1.0, -1.0, 'right', -1, 1, 7);
INSERT INTO Station VALUES (119, 117, 'Transfer', 532.0, 373.0, 55.76157, 37.62428, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (120, 118, 'Transfer', 595.0, 436.0, 55.755283, 37.633003, 0.0, -1.0, -1.0, 'none', 93, 1, 7);
INSERT INTO Station VALUES (121, 119, 'Transfer', 680.0, 521.0, 55.739487, 37.65325, 0.0, -1.0, -1.0, 'none', 75, 1, 7);
INSERT INTO Station VALUES (122, 120, 'Transfer', 776.0, 576.0, 55.731953, 37.66588, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (123, 121, 'Station', 835.0, 635.0, 55.72484, 37.68714, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (124, 122, 'Station', 835.0, 655.0, 55.70864, 37.730743, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (125, 123, 'Station', 835.0, 675.0, 55.705353, 37.765675, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (126, 124, 'Station', 835.0, 695.0, 55.71691, 37.793224, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (127, 125, 'Station', 835.0, 715.0, 55.7157, 37.818108, 0.0, -1.0, -1.0, 'left', -1, 1, 7);
INSERT INTO Station VALUES (128, 126, 'Station', 835.0, 387.0, 55.751755, 37.816055, 0.0, -1.0, -1.0, 'left', -1, 1, 8);
INSERT INTO Station VALUES (129, 127, 'Station', 835.0, 407.0, 55.751026, 37.78593, 0.0, -1.0, -1.0, 'left', -1, 1, 8);
INSERT INTO Station VALUES (130, 128, 'Station', 835.0, 427.0, 55.75813, 37.751682, 0.0, -1.0, -1.0, 'left', -1, 1, 8);
INSERT INTO Station VALUES (131, 129, 'Station', 835.0, 447.0, 55.75151, 37.71701, 0.0, -1.0, -1.0, 'left', -1, 1, 8);
INSERT INTO Station VALUES (132, 130, 'Transfer', 776.0, 506.0, 55.74748, 37.682312, 0.0, -1.0, -1.0, 'left', -1, 1, 8);
INSERT INTO Station VALUES (133, 131, 'Transfer', 680.0, 506.0, 55.740795, 37.65652, 0.0, -1.0, -1.0, 'right', -1, 1, 8);
INSERT INTO Station VALUES (134, 132, 'Transfer', 558.0, 506.0, 55.74071, 37.625664, 0.0, -1.0, -1.0, 'none', 94, 1, 8);
INSERT INTO Station VALUES (135, 133, 'Station', 462.0, 20.0, 55.897648, 37.587147, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (136, 134, 'Station', 462.0, 40.0, 55.88388, 37.603626, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (137, 135, 'Station', 462.0, 60.0, 55.86327, 37.60474, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (138, 136, 'Station', 462.0, 80.0, 55.847134, 37.589893, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (139, 137, 'Station', 462.0, 100.0, 55.836628, 37.575516, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (140, 138, 'Station', 462.0, 120.0, 55.819057, 37.57543, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (141, 139, 'Station', 462.0, 140.0, 55.807938, 37.581055, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (142, 140, 'Station', 462.0, 160.0, 55.793995, 37.589207, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (143, 141, 'Transfer', 462.0, 193.0, 55.78179, 37.598778, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (144, 142, 'Transfer', 511.0, 272.0, 55.77164, 37.620358, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (145, 143, 'Transfer', 395.0, 388.0, 55.76581, 37.608173, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (146, 144, 'Transfer', 395.0, 495.0, 55.75087, 37.60678, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (147, 145, 'Station', 500.0, 600.0, 55.7368, 37.61868, 0.0, -1.0, -1.0, 'left', -1, 1, 9);
INSERT INTO Station VALUES (148, 146, 'Transfer', 545.0, 645.0, 55.72681, 37.62516, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (149, 147, 'Station', 545.0, 680.0, 55.70864, 37.62251, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (150, 148, 'Station', 545.0, 700.0, 55.682667, 37.621822, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (151, 149, 'Station', 545.0, 720.0, 55.67294, 37.61075, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (152, 150, 'Station', 545.0, 740.0, 55.662773, 37.6056, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (153, 151, 'Transfer', 545.0, 775.0, 55.65133, 37.598385, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (154, 152, 'Station', 545.0, 795.0, 55.6404, 37.60577, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (155, 153, 'Station', 545.0, 815.0, 55.62223, 37.609035, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (156, 154, 'Station', 545.0, 835.0, 55.611855, 37.603798, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (157, 155, 'Station', 545.0, 855.0, 55.59542, 37.601223, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (158, 156, 'Station', 545.0, 875.0, 55.583633, 37.59676, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (159, 157, 'Transfer', 545.0, 895.0, 55.570194, 37.57719, 0.0, -1.0, -1.0, 'right', -1, 1, 9);
INSERT INTO Station VALUES (160, 181, 'Station', 527.0, 166.0, 55.795467, 37.616093, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (161, 182, 'Station', 527.0, 186.0, 55.781353, 37.613693, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (162, 158, 'Transfer', 527.0, 272.0, 55.767628, 37.621906, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (163, 159, 'Transfer', 595.0, 340.0, 55.76752, 37.639122, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (164, 160, 'Transfer', 714.0, 459.0, 55.756252, 37.657764, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (165, 161, 'Transfer', 776.0, 521.0, 55.746403, 37.683037, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (166, 162, 'Transfer', 776.0, 561.0, 55.732967, 37.666985, 0.0, -1.0, -1.0, 'left', -1, 1, 10);
INSERT INTO Station VALUES (167, 163, 'Station', 776.0, 635.0, 55.71778, 37.676582, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (168, 164, 'Station', 776.0, 655.0, 55.706135, 37.685493, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (169, 165, 'Station', 776.0, 675.0, 55.692875, 37.727654, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (170, 166, 'Station', 776.0, 695.0, 55.69084, 37.75426, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (171, 167, 'Station', 776.0, 715.0, 55.676228, 37.761898, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (172, 168, 'Station', 776.0, 735.0, 55.65943, 37.750484, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (173, 169, 'Station', 776.0, 755.0, 55.650085, 37.74379, 0.0, -1.0, -1.0, 'right', -1, 1, 10);
INSERT INTO Station VALUES (174, 170, 'Transfer', 665.0, 715.0, 55.65512, 37.648273, 0.0, -1.0, -1.0, 'none', 34, 1, 11);
INSERT INTO Station VALUES (175, 171, 'Station', 579.0, 747.0, 55.653477, 37.62045, 0.0, -1.0, -1.0, 'left', -1, 1, 11);
INSERT INTO Station VALUES (176, 172, 'Transfer', 545.0, 760.0, 55.65306, 37.598305, 0.0, -1.0, -1.0, 'right', -1, 1, 11);
INSERT INTO Station VALUES (177, 173, 'Transfer', 545.0, 910.0, 55.568398, 37.575905, 0.0, -1.0, -1.0, 'left', -1, 1, 12);
INSERT INTO Station VALUES (178, 174, 'Station', 545.0, 930.0, 55.548058, 37.55462, 0.0, -1.0, -1.0, 'left', -1, 1, 12);
INSERT INTO Station VALUES (179, 175, 'Station', 545.0, 950.0, 55.54545, 37.54325, 0.0, -1.0, -1.0, 'left', -1, 1, 12);
INSERT INTO Station VALUES (180, 176, 'Station', 545.0, 970.0, 55.54175, 37.530804, 0.0, -1.0, -1.0, 'left', -1, 1, 12);
INSERT INTO Station VALUES (181, 177, 'Station', 545.0, 990.0, 55.538162, 37.516514, 0.0, -1.0, -1.0, 'left', -1, 1, 12);
INSERT INTO Station VALUES (182, 1, 'Station', 295.0, 20.0, 53.94583, 27.689722, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (183, 2, 'Station', 285.0, 40.0, 53.939167, 27.667221, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (184, 3, 'Station', 275.0, 60.0, 53.934563, 27.651031, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (185, 4, 'Station', 265.0, 80.0, 53.927975, 27.62735, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (186, 5, 'Station', 255.0, 100.0, 53.9244, 27.613886, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (187, 6, 'Station', 245.0, 120.0, 53.92162, 27.597143, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (188, 7, 'Station', 235.0, 140.0, 53.915962, 27.583887, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (189, 8, 'Station', 225.0, 160.0, 53.908962, 27.574492, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (190, 9, 'Transfer', 210.0, 190.0, 53.901665, 27.560833, 0.0, -1.0, -1.0, 'left', -1, 13, 1);
INSERT INTO Station VALUES (191, 10, 'Station', 192.0, 226.0, 53.891666, 27.547966, 0.0, -1.0, -1.0, 'right', -1, 13, 1);
INSERT INTO Station VALUES (192, 11, 'Station', 182.0, 246.0, 53.88524, 27.539858, 0.0, -1.0, -1.0, 'right', -1, 13, 1);
INSERT INTO Station VALUES (193, 12, 'Station', 120.0, 40.0, 53.906944, 27.435278, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (194, 13, 'Station', 130.0, 60.0, 53.906387, 27.455555, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (195, 14, 'Station', 140.0, 80.0, 53.908333, 27.479166, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (196, 15, 'Station', 150.0, 100.0, 53.909443, 27.495277, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (197, 16, 'Station', 160.0, 120.0, 53.906387, 27.52111, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (198, 17, 'Station', 170.0, 140.0, 53.905277, 27.539444, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (199, 18, 'Station', 180.0, 160.0, 53.905834, 27.553888, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (200, 19, 'Transfer', 195.0, 190.0, 53.901703, 27.56096, 0.0, -1.0, -1.0, 'right', -1, 13, 2);
INSERT INTO Station VALUES (201, 20, 'Station', 213.0, 226.0, 53.893887, 27.570276, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (202, 21, 'Station', 223.0, 246.0, 53.889984, 27.586555, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (203, 22, 'Station', 233.0, 266.0, 53.889824, 27.615055, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (204, 23, 'Station', 243.0, 286.0, 53.874596, 27.630144, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (205, 24, 'Station', 253.0, 306.0, 53.869045, 27.648647, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (206, 25, 'Station', 263.0, 326.0, 53.861996, 27.674301, 0.0, -1.0, -1.0, 'left', -1, 13, 2);
INSERT INTO Station VALUES (207, 1, 'Station', 378.0, 15.0, 60.05019, 30.442944, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (208, 2, 'Station', 378.0, 35.0, 60.03493, 30.418224, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (209, 3, 'Station', 378.0, 55.0, 60.012802, 30.39608, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (210, 4, 'Station', 378.0, 75.0, 60.00894, 30.37089, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (211, 5, 'Station', 378.0, 95.0, 59.999844, 30.366125, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (212, 6, 'Station', 378.0, 115.0, 59.984947, 30.344238, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (213, 7, 'Station', 378.0, 135.0, 59.971657, 30.348488, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (214, 8, 'Station', 378.0, 155.0, 59.957268, 30.355396, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (215, 9, 'Station', 378.0, 175.0, 59.944523, 30.359901, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (216, 10, 'Transfer', 378.0, 205.0, 59.93027, 30.361061, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (217, 11, 'Transfer', 333.0, 250.0, 59.927624, 30.347885, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (218, 12, 'Transfer', 263.0, 320.0, 59.920643, 30.329603, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (219, 13, 'Transfer', 208.0, 375.0, 59.916515, 30.31849, 0.0, -1.0, -1.0, 'left', -1, 2, 1);
INSERT INTO Station VALUES (220, 14, 'Station', 168.0, 440.0, 59.90721, 30.299585, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (221, 15, 'Station', 168.0, 460.0, 59.90122, 30.274908, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (222, 16, 'Station', 168.0, 480.0, 59.87969, 30.261927, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (223, 17, 'Station', 168.0, 500.0, 59.867325, 30.261347, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (224, 18, 'Station', 168.0, 520.0, 59.851173, 30.268278, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (225, 19, 'Station', 168.0, 540.0, 59.84184, 30.25195, 0.0, -1.0, -1.0, 'right', -1, 2, 1);
INSERT INTO Station VALUES (226, 20, 'Station', 208.0, 15.0, 60.066982, 30.333853, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (227, 21, 'Station', 208.0, 35.0, 60.051476, 30.332565, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (228, 22, 'Station', 208.0, 55.0, 60.037117, 30.321493, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (229, 23, 'Station', 208.0, 75.0, 60.016705, 30.31557, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (230, 24, 'Station', 208.0, 95.0, 60.002506, 30.296774, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (231, 25, 'Station', 208.0, 115.0, 59.985466, 30.300852, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (232, 26, 'Station', 208.0, 135.0, 59.96635, 30.311028, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (233, 27, 'Station', 208.0, 155.0, 59.956196, 30.318913, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (234, 28, 'Transfer', 208.0, 205.0, 59.935043, 30.329733, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (235, 29, 'Transfer', 208.0, 250.0, 59.92713, 30.320333, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (236, 30, 'Transfer', 208.0, 390.0, 59.916515, 30.31849, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (237, 31, 'Station', 208.0, 420.0, 59.906265, 30.31746, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (238, 32, 'Station', 208.0, 440.0, 59.89178, 30.317888, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (239, 33, 'Station', 208.0, 460.0, 59.879185, 30.31866, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (240, 34, 'Station', 208.0, 480.0, 59.866344, 30.321795, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (241, 35, 'Station', 208.0, 500.0, 59.851345, 30.321535, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (242, 36, 'Station', 208.0, 520.0, 59.833237, 30.34943, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (243, 37, 'Station', 208.0, 540.0, 59.829807, 30.375652, 0.0, -1.0, -1.0, 'left', -1, 2, 2);
INSERT INTO Station VALUES (244, 38, 'Station', 126.0, 135.0, 59.94852, 30.23446, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (245, 39, 'Station', 126.0, 155.0, 59.94259, 30.278234, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (246, 40, 'Transfer', 208.0, 220.0, 59.933926, 30.333424, 0.0, -1.0, -1.0, 'left', -1, 2, 3);
INSERT INTO Station VALUES (247, 41, 'Transfer', 378.0, 220.0, 59.931366, 30.354624, 0.0, -1.0, -1.0, 'left', -1, 2, 3);
INSERT INTO Station VALUES (248, 42, 'Transfer', 558.0, 275.0, 59.924484, 30.385078, 0.0, -1.0, -1.0, 'left', -1, 2, 3);
INSERT INTO Station VALUES (249, 43, 'Station', 558.0, 325.0, 59.896687, 30.423676, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (250, 44, 'Station', 558.0, 345.0, 59.877354, 30.441698, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (251, 45, 'Station', 558.0, 365.0, 59.865223, 30.470282, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (252, 46, 'Station', 558.0, 385.0, 59.848717, 30.457748, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (253, 47, 'Station', 558.0, 405.0, 59.830994, 30.501266, 0.0, -1.0, -1.0, 'right', -1, 2, 3);
INSERT INTO Station VALUES (254, 48, 'Transfer', 208.0, 265.0, 59.92715, 30.318907, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (255, 49, 'Transfer', 333.0, 265.0, 59.928226, 30.34604, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (256, 50, 'Station', 438.0, 265.0, 59.92083, 30.355053, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (257, 51, 'Transfer', 558.0, 290.0, 59.923603, 30.383232, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (258, 52, 'Station', 598.0, 345.0, 59.92909, 30.411917, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (259, 53, 'Station', 598.0, 365.0, 59.93242, 30.439253, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (260, 54, 'Station', 598.0, 385.0, 59.919838, 30.466763, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (261, 55, 'Station', 598.0, 405.0, 59.907425, 30.483328, 0.0, -1.0, -1.0, 'left', -1, 2, 4);
INSERT INTO Station VALUES (262, 56, 'Station', 168.0, 15.0, 60.0086, 30.258665, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (263, 57, 'Station', 168.0, 35.0, 59.989437, 30.255146, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (264, 58, 'Station', 168.0, 55.0, 59.97183, 30.259438, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (265, 59, 'Station', 168.0, 75.0, 59.961025, 30.29201, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (266, 60, 'Station', 168.0, 95.0, 59.952023, 30.291325, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (267, 61, 'Transfer', 208.0, 280.0, 59.926743, 30.31776, 0.0, -1.0, -1.0, 'right', -1, 2, 5);
INSERT INTO Station VALUES (268, 62, 'Transfer', 263.0, 335.0, 59.922356, 30.335688, 0.0, -1.0, -1.0, 'left', -1, 2, 5);
INSERT INTO Station VALUES (269, 63, 'Station', 283.0, 355.0, 59.89602, 30.357542, 0.0, -1.0, -1.0, 'left', -1, 2, 5);
INSERT INTO Station VALUES (270, 1, 'Station', 120.0, 75.0, 50.46488, 30.354795, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (271, 2, 'Station', 140.0, 95.0, 50.45622, 30.363766, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (272, 3, 'Station', 160.0, 115.0, 50.45767, 30.391874, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (273, 4, 'Station', 180.0, 135.0, 50.458897, 30.404793, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (274, 5, 'Station', 200.0, 155.0, 50.458748, 30.420542, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (275, 6, 'Station', 220.0, 175.0, 50.45488, 30.445326, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (276, 7, 'Station', 240.0, 195.0, 50.45096, 30.466719, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (277, 8, 'Station', 260.0, 215.0, 50.441612, 30.488369, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (278, 9, 'Station', 280.0, 235.0, 50.4441, 30.505816, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (279, 10, 'Transfer', 370.0, 185.0, 50.445385, 30.518625, 0.0, -1.0, -1.0, 'right', -1, 8, 1);
INSERT INTO Station VALUES (280, 11, 'Transfer', 440.0, 185.0, 50.44745, 30.52562, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (281, 12, 'Station', 470.0, 215.0, 50.444347, 30.54534, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (282, 13, 'Station', 490.0, 235.0, 50.440998, 30.558537, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (283, 14, 'Station', 600.0, 235.0, 50.446068, 30.576967, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (284, 15, 'Station', 620.0, 215.0, 50.451847, 30.597998, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (285, 16, 'Station', 640.0, 195.0, 50.456493, 30.613853, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (286, 17, 'Station', 660.0, 175.0, 50.459743, 30.630398, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (287, 18, 'Station', 680.0, 155.0, 50.46439, 30.64441, 0.0, -1.0, -1.0, 'left', -1, 8, 1);
INSERT INTO Station VALUES (288, 19, 'Station', 440.0, 15.0, 50.52254, 30.499012, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (289, 20, 'Station', 440.0, 35.0, 50.512184, 30.498497, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (290, 21, 'Station', 440.0, 55.0, 50.501705, 30.499077, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (291, 22, 'Station', 440.0, 75.0, 50.486073, 30.497917, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (292, 23, 'Station', 440.0, 95.0, 50.473347, 30.505041, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (293, 24, 'Station', 440.0, 115.0, 50.465797, 30.515234, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (294, 25, 'Station', 440.0, 135.0, 50.45894, 30.524977, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (295, 26, 'Transfer', 440.0, 170.0, 50.449825, 30.523968, 0.0, -1.0, -1.0, 'left', -1, 8, 2);
INSERT INTO Station VALUES (296, 27, 'Transfer', 440.0, 285.0, 50.43959, 30.516865, 0.0, -1.0, -1.0, 'right', -1, 8, 2);
INSERT INTO Station VALUES (297, 28, 'Station', 440.0, 320.0, 50.43224, 30.5165, 0.0, -1.0, -1.0, 'right', -1, 8, 2);
INSERT INTO Station VALUES (298, 29, 'Station', 440.0, 340.0, 50.42066, 30.520771, 0.0, -1.0, -1.0, 'right', -1, 8, 2);
INSERT INTO Station VALUES (299, 30, 'Station', 440.0, 360.0, 50.412907, 30.52461, 0.0, -1.0, -1.0, 'right', -1, 8, 2);
INSERT INTO Station VALUES (300, 31, 'Station', 370.0, 95.0, 50.476395, 30.43082, 0.0, -1.0, -1.0, 'right', -1, 8, 3);
INSERT INTO Station VALUES (301, 32, 'Station', 370.0, 115.0, 50.473473, 30.4482, 0.0, -1.0, -1.0, 'right', -1, 8, 3);
INSERT INTO Station VALUES (302, 33, 'Station', 370.0, 135.0, 50.461792, 30.481955, 0.0, -1.0, -1.0, 'right', -1, 8, 3);
INSERT INTO Station VALUES (303, 34, 'Transfer', 370.0, 170.0, 50.44831, 30.513582, 0.0, -1.0, -1.0, 'right', -1, 8, 3);
INSERT INTO Station VALUES (304, 35, 'Transfer', 440.0, 270.0, 50.437992, 30.52107, 0.0, -1.0, -1.0, 'right', -1, 8, 3);
INSERT INTO Station VALUES (305, 36, 'Station', 460.0, 290.0, 50.436764, 30.531994, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (306, 37, 'Station', 480.0, 310.0, 50.427494, 30.53901, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (307, 38, 'Station', 500.0, 330.0, 50.41816, 30.544952, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (308, 39, 'Station', 520.0, 350.0, 50.401215, 30.561668, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (309, 40, 'Station', 630.0, 350.0, 50.394238, 30.60437, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (310, 41, 'Station', 650.0, 330.0, 50.39614, 30.616343, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (311, 42, 'Station', 670.0, 310.0, 50.397877, 30.633831, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (312, 43, 'Station', 690.0, 290.0, 50.400654, 30.651814, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (313, 44, 'Station', 710.0, 270.0, 50.403183, 30.670889, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (314, 45, 'Station', 730.0, 250.0, 50.403606, 30.682968, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (315, 46, 'Station', 750.0, 230.0, 50.40889, 30.694445, 0.0, -1.0, -1.0, 'left', -1, 8, 3);
INSERT INTO Station VALUES (316, 1, 'Station', 100.0, 300.0, 49.98287, 36.182076, 0.0, -1.0, -1.0, 'right', -1, 9, 1);
INSERT INTO Station VALUES (317, 2, 'Station', 120.0, 280.0, 49.9896, 36.20519, 0.0, -1.0, -1.0, 'right', -1, 9, 1);
INSERT INTO Station VALUES (318, 3, 'Station', 140.0, 260.0, 49.992786, 36.2198, 0.0, -1.0, -1.0, 'right', -1, 9, 1);
INSERT INTO Station VALUES (319, 4, 'Transfer', 190.0, 210.0, 49.99124, 36.232246, 0.0, -1.0, -1.0, 'right', -1, 9, 1);
INSERT INTO Station VALUES (320, 5, 'Station', 215.0, 235.0, 49.980633, 36.243145, 0.0, -1.0, -1.0, 'right', -1, 9, 1);
INSERT INTO Station VALUES (321, 6, 'Transfer', 240.0, 260.0, 49.979183, 36.260933, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (322, 7, 'Station', 270.0, 290.0, 49.975708, 36.28087, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (323, 8, 'Station', 290.0, 310.0, 49.972214, 36.301746, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (324, 9, 'Station', 310.0, 330.0, 49.96606, 36.32121, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (325, 10, 'Station', 330.0, 350.0, 49.961685, 36.343033, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (326, 11, 'Station', 350.0, 370.0, 49.958164, 36.360455, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (327, 12, 'Station', 370.0, 390.0, 49.95289, 36.378906, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (328, 13, 'Station', 390.0, 410.0, 49.946236, 36.398823, 0.0, -1.0, -1.0, 'left', -1, 9, 1);
INSERT INTO Station VALUES (329, 14, 'Station', 370.0, 15.0, 50.024643, 36.33582, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (330, 15, 'Station', 350.0, 35.0, 50.01669, 36.329987, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (331, 16, 'Station', 330.0, 55.0, 50.00927, 36.31848, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (332, 17, 'Station', 310.0, 75.0, 50.002098, 36.302906, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (333, 18, 'Station', 290.0, 95.0, 50.00109, 36.270138, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (334, 19, 'Station', 270.0, 115.0, 50.003944, 36.2475, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (335, 20, 'Transfer', 240.0, 145.0, 49.99847, 36.240097, 0.0, -1.0, -1.0, 'left', -1, 9, 2);
INSERT INTO Station VALUES (336, 21, 'Transfer', 190.0, 195.0, 49.99316, 36.230827, 0.0, -1.0, -1.0, 'right', -1, 9, 2);
INSERT INTO Station VALUES (337, 22, 'Station', 240.0, 75.0, 50.034637, 36.22025, 0.0, -1.0, -1.0, 'right', -1, 9, 3);
INSERT INTO Station VALUES (338, 23, 'Station', 240.0, 95.0, 50.026684, 36.22304, 0.0, -1.0, -1.0, 'right', -1, 9, 3);
INSERT INTO Station VALUES (339, 24, 'Station', 240.0, 115.0, 50.013035, 36.226837, 0.0, -1.0, -1.0, 'right', -1, 9, 3);
INSERT INTO Station VALUES (340, 25, 'Transfer', 240.0, 160.0, 50.005974, 36.231194, 0.0, -1.0, -1.0, 'left', -1, 9, 3);
INSERT INTO Station VALUES (341, 26, 'Station', 240.0, 193.0, 49.99847, 36.240097, 0.0, -1.0, -1.0, 'left', -1, 9, 3);
INSERT INTO Station VALUES (342, 27, 'Station', 240.0, 213.0, 49.98862, 36.26475, 0.0, -1.0, -1.0, 'left', -1, 9, 3);
INSERT INTO Station VALUES (343, 28, 'Transfer', 240.0, 246.0, 49.978592, 36.26265, 0.0, -1.0, -1.0, 'left', -1, 9, 3);
INSERT INTO Link VALUES (0, 190, 0, 1, 1, 2);
INSERT INTO Link VALUES (1, 145, 0, 1, 2, 3);
INSERT INTO Link VALUES (2, 200, 0, 1, 3, 4);
INSERT INTO Link VALUES (3, 135, 0, 1, 4, 5);
INSERT INTO Link VALUES (4, 115, 0, 1, 5, 6);
INSERT INTO Link VALUES (5, 110, 0, 1, 6, 7);
INSERT INTO Link VALUES (6, 100, 0, 1, 7, 8);
INSERT INTO Link VALUES (7, 115, 0, 1, 8, 9);
INSERT INTO Link VALUES (8, 180, 1, 1, 8, 92);
INSERT INTO Link VALUES (9, 180, 1, 1, 8, 159);
INSERT INTO Link VALUES (10, 100, 0, 1, 9, 10);
INSERT INTO Link VALUES (11, 180, 1, 1, 9, 117);
INSERT INTO Link VALUES (12, 105, 0, 1, 10, 11);
INSERT INTO Link VALUES (13, 300, 1, 1, 10, 29);
INSERT INTO Link VALUES (14, 360, 1, 1, 11, 144);
INSERT INTO Link VALUES (15, 115, 0, 1, 11, 12);
INSERT INTO Link VALUES (16, 180, 1, 1, 11, 68);
INSERT INTO Link VALUES (17, 300, 1, 1, 11, 49);
INSERT INTO Link VALUES (18, 130, 0, 1, 12, 13);
INSERT INTO Link VALUES (19, 150, 0, 1, 13, 14);
INSERT INTO Link VALUES (20, 95, 0, 1, 14, 15);
INSERT INTO Link VALUES (21, 185, 0, 1, 15, 16);
INSERT INTO Link VALUES (22, 225, 0, 1, 16, 17);
INSERT INTO Link VALUES (23, 180, 0, 1, 17, 18);
INSERT INTO Link VALUES (24, 170, 0, 1, 18, 19);
INSERT INTO Link VALUES (25, 155, 0, 1, 20, 21);
INSERT INTO Link VALUES (26, 190, 0, 1, 21, 22);
INSERT INTO Link VALUES (27, 175, 0, 1, 22, 23);
INSERT INTO Link VALUES (28, 130, 0, 1, 23, 24);
INSERT INTO Link VALUES (29, 170, 0, 1, 24, 25);
INSERT INTO Link VALUES (30, 185, 0, 1, 25, 26);
INSERT INTO Link VALUES (31, 115, 0, 1, 26, 27);
INSERT INTO Link VALUES (32, 105, 0, 1, 27, 28);
INSERT INTO Link VALUES (33, 105, 0, 1, 28, 29);
INSERT INTO Link VALUES (34, 180, 1, 1, 28, 116);
INSERT INTO Link VALUES (35, 240, 1, 1, 28, 143);
INSERT INTO Link VALUES (36, 165, 0, 1, 29, 30);
INSERT INTO Link VALUES (37, 240, 1, 1, 29, 48);
INSERT INTO Link VALUES (38, 180, 1, 1, 30, 132);
INSERT INTO Link VALUES (39, 140, 0, 1, 30, 31);
INSERT INTO Link VALUES (40, 180, 1, 1, 30, 94);
INSERT INTO Link VALUES (41, 205, 0, 1, 31, 32);
INSERT INTO Link VALUES (42, 275, 0, 1, 32, 33);
INSERT INTO Link VALUES (43, 230, 0, 1, 33, 34);
INSERT INTO Link VALUES (44, 205, 0, 1, 34, 35);
INSERT INTO Link VALUES (45, 120, 1, 1, 34, 170);
INSERT INTO Link VALUES (46, 145, 0, 1, 35, 36);
INSERT INTO Link VALUES (47, 165, 0, 1, 36, 37);
INSERT INTO Link VALUES (48, 145, 0, 1, 37, 38);
INSERT INTO Link VALUES (49, 150, 0, 1, 38, 39);
INSERT INTO Link VALUES (50, 135, 0, 1, 40, 41);
INSERT INTO Link VALUES (51, 170, 0, 1, 41, 42);
INSERT INTO Link VALUES (52, 190, 0, 1, 42, 43);
INSERT INTO Link VALUES (53, 165, 0, 1, 43, 44);
INSERT INTO Link VALUES (54, 110, 0, 1, 44, 45);
INSERT INTO Link VALUES (55, 145, 0, 1, 45, 46);
INSERT INTO Link VALUES (56, 175, 0, 1, 46, 47);
INSERT INTO Link VALUES (57, 180, 1, 1, 47, 160);
INSERT INTO Link VALUES (58, 185, 0, 1, 47, 48);
INSERT INTO Link VALUES (59, 125, 0, 1, 48, 49);
INSERT INTO Link VALUES (60, 180, 1, 1, 49, 144);
INSERT INTO Link VALUES (61, 180, 1, 1, 49, 68);
INSERT INTO Link VALUES (62, 140, 0, 1, 49, 50);
INSERT INTO Link VALUES (63, 105, 0, 1, 50, 51);
INSERT INTO Link VALUES (64, 240, 1, 1, 51, 65);
INSERT INTO Link VALUES (65, 270, 0, 1, 51, 52);
INSERT INTO Link VALUES (66, 260, 0, 1, 52, 53);
INSERT INTO Link VALUES (67, 170, 0, 1, 53, 54);
INSERT INTO Link VALUES (68, 180, 1, 1, 54, 58);
INSERT INTO Link VALUES (69, 180, 0, 1, 54, 55);
INSERT INTO Link VALUES (70, 195, 0, 1, 55, 56);
INSERT INTO Link VALUES (71, 535, 0, 1, 56, 57);
INSERT INTO Link VALUES (72, 205, 0, 1, 57, 178);
INSERT INTO Link VALUES (73, 180, 0, 1, 178, 179);
INSERT INTO Link VALUES (74, 170, 0, 1, 179, 180);
INSERT INTO Link VALUES (75, 130, 0, 1, 58, 59);
INSERT INTO Link VALUES (76, 115, 0, 1, 59, 60);
INSERT INTO Link VALUES (77, 115, 0, 1, 60, 61);
INSERT INTO Link VALUES (78, 140, 0, 1, 61, 62);
INSERT INTO Link VALUES (79, 145, 0, 1, 62, 63);
INSERT INTO Link VALUES (80, 120, 0, 1, 63, 64);
INSERT INTO Link VALUES (81, 140, 0, 1, 64, 65);
INSERT INTO Link VALUES (82, 395, 0, 1, 65, 69);
INSERT INTO Link VALUES (83, 130, 0, 1, 65, 66);
INSERT INTO Link VALUES (84, 115, 0, 1, 66, 67);
INSERT INTO Link VALUES (85, 65, 0, 1, 67, 68);
INSERT INTO Link VALUES (86, 120, 0, 1, 69, 70);
INSERT INTO Link VALUES (87, 120, 0, 1, 71, 72);
INSERT INTO Link VALUES (88, 300, 1, 1, 71, 13);
INSERT INTO Link VALUES (89, 105, 0, 1, 72, 73);
INSERT INTO Link VALUES (90, 180, 1, 1, 72, 95);
INSERT INTO Link VALUES (91, 180, 1, 1, 73, 146);
INSERT INTO Link VALUES (92, 115, 0, 1, 73, 74);
INSERT INTO Link VALUES (93, 240, 1, 1, 74, 31);
INSERT INTO Link VALUES (94, 135, 0, 1, 74, 75);
INSERT INTO Link VALUES (95, 180, 1, 1, 75, 119);
INSERT INTO Link VALUES (96, 180, 1, 1, 75, 131);
INSERT INTO Link VALUES (97, 170, 0, 1, 75, 76);
INSERT INTO Link VALUES (98, 360, 1, 1, 76, 160);
INSERT INTO Link VALUES (99, 240, 1, 1, 76, 47);
INSERT INTO Link VALUES (100, 175, 0, 1, 76, 77);
INSERT INTO Link VALUES (101, 160, 0, 1, 77, 78);
INSERT INTO Link VALUES (102, 360, 1, 1, 77, 6);
INSERT INTO Link VALUES (103, 160, 0, 1, 78, 79);
INSERT INTO Link VALUES (104, 180, 1, 1, 78, 90);
INSERT INTO Link VALUES (105, 180, 1, 1, 79, 141);
INSERT INTO Link VALUES (106, 135, 0, 1, 79, 80);
INSERT INTO Link VALUES (107, 165, 0, 1, 80, 81);
INSERT INTO Link VALUES (108, 160, 0, 1, 81, 82);
INSERT INTO Link VALUES (109, 180, 1, 1, 81, 115);
INSERT INTO Link VALUES (110, 360, 1, 1, 82, 65);
INSERT INTO Link VALUES (111, 180, 1, 1, 82, 51);
INSERT INTO Link VALUES (112, 175, 0, 1, 82, 71);
INSERT INTO Link VALUES (113, 160, 0, 1, 83, 84);
INSERT INTO Link VALUES (114, 140, 0, 1, 84, 85);
INSERT INTO Link VALUES (115, 135, 0, 1, 85, 86);
INSERT INTO Link VALUES (116, 210, 0, 1, 86, 87);
INSERT INTO Link VALUES (117, 135, 0, 1, 87, 88);
INSERT INTO Link VALUES (118, 140, 0, 1, 88, 89);
INSERT INTO Link VALUES (119, 130, 0, 1, 89, 90);
INSERT INTO Link VALUES (120, 120, 0, 1, 90, 91);
INSERT INTO Link VALUES (121, 100, 0, 1, 91, 92);
INSERT INTO Link VALUES (122, 125, 0, 1, 92, 93);
INSERT INTO Link VALUES (123, 180, 1, 1, 92, 159);
INSERT INTO Link VALUES (124, 170, 0, 1, 93, 94);
INSERT INTO Link VALUES (125, 120, 1, 1, 93, 118);
INSERT INTO Link VALUES (126, 155, 0, 1, 94, 95);
INSERT INTO Link VALUES (127, 120, 1, 1, 94, 132);
INSERT INTO Link VALUES (128, 130, 0, 1, 95, 96);
INSERT INTO Link VALUES (129, 190, 0, 1, 96, 97);
INSERT INTO Link VALUES (130, 185, 0, 1, 97, 98);
INSERT INTO Link VALUES (131, 120, 0, 1, 98, 99);
INSERT INTO Link VALUES (132, 100, 0, 1, 99, 100);
INSERT INTO Link VALUES (133, 140, 0, 1, 100, 101);
INSERT INTO Link VALUES (134, 170, 0, 1, 101, 102);
INSERT INTO Link VALUES (135, 115, 0, 1, 102, 103);
INSERT INTO Link VALUES (136, 150, 0, 1, 103, 104);
INSERT INTO Link VALUES (137, 170, 0, 1, 104, 105);
INSERT INTO Link VALUES (138, 140, 0, 1, 105, 106);
INSERT INTO Link VALUES (139, 110, 0, 1, 107, 108);
INSERT INTO Link VALUES (140, 175, 0, 1, 108, 109);
INSERT INTO Link VALUES (141, 240, 0, 1, 109, 110);
INSERT INTO Link VALUES (142, 185, 0, 1, 110, 111);
INSERT INTO Link VALUES (143, 200, 0, 1, 111, 112);
INSERT INTO Link VALUES (144, 150, 0, 1, 112, 113);
INSERT INTO Link VALUES (145, 130, 0, 1, 113, 114);
INSERT INTO Link VALUES (146, 125, 0, 1, 114, 115);
INSERT INTO Link VALUES (147, 165, 0, 1, 115, 116);
INSERT INTO Link VALUES (148, 120, 0, 1, 116, 117);
INSERT INTO Link VALUES (149, 240, 1, 1, 116, 143);
INSERT INTO Link VALUES (150, 90, 0, 1, 117, 118);
INSERT INTO Link VALUES (151, 170, 0, 1, 118, 119);
INSERT INTO Link VALUES (152, 145, 0, 1, 119, 120);
INSERT INTO Link VALUES (153, 240, 1, 1, 119, 131);
INSERT INTO Link VALUES (154, 150, 0, 1, 120, 121);
INSERT INTO Link VALUES (155, 180, 1, 1, 120, 162);
INSERT INTO Link VALUES (156, 245, 0, 1, 121, 122);
INSERT INTO Link VALUES (157, 185, 0, 1, 122, 123);
INSERT INTO Link VALUES (158, 185, 0, 1, 123, 124);
INSERT INTO Link VALUES (159, 170, 0, 1, 124, 125);
INSERT INTO Link VALUES (160, 150, 0, 1, 126, 127);
INSERT INTO Link VALUES (161, 195, 0, 1, 127, 128);
INSERT INTO Link VALUES (162, 150, 0, 1, 128, 129);
INSERT INTO Link VALUES (163, 180, 0, 1, 129, 130);
INSERT INTO Link VALUES (164, 175, 0, 1, 130, 131);
INSERT INTO Link VALUES (165, 180, 1, 1, 130, 161);
INSERT INTO Link VALUES (166, 160, 0, 1, 131, 132);
INSERT INTO Link VALUES (167, 150, 0, 1, 133, 134);
INSERT INTO Link VALUES (168, 195, 0, 1, 134, 135);
INSERT INTO Link VALUES (169, 165, 0, 1, 135, 136);
INSERT INTO Link VALUES (170, 145, 0, 1, 136, 137);
INSERT INTO Link VALUES (171, 195, 0, 1, 137, 138);
INSERT INTO Link VALUES (172, 100, 0, 1, 138, 139);
INSERT INTO Link VALUES (173, 115, 0, 1, 139, 140);
INSERT INTO Link VALUES (174, 115, 0, 1, 140, 141);
INSERT INTO Link VALUES (175, 155, 0, 1, 141, 142);
INSERT INTO Link VALUES (176, 180, 1, 1, 142, 158);
INSERT INTO Link VALUES (177, 100, 0, 1, 142, 143);
INSERT INTO Link VALUES (178, 150, 0, 1, 143, 144);
INSERT INTO Link VALUES (179, 140, 0, 1, 144, 145);
INSERT INTO Link VALUES (180, 115, 0, 1, 145, 146);
INSERT INTO Link VALUES (181, 205, 0, 1, 146, 147);
INSERT INTO Link VALUES (182, 225, 0, 1, 147, 148);
INSERT INTO Link VALUES (183, 120, 0, 1, 148, 149);
INSERT INTO Link VALUES (184, 100, 0, 1, 149, 150);
INSERT INTO Link VALUES (185, 110, 0, 1, 150, 151);
INSERT INTO Link VALUES (186, 120, 1, 1, 151, 172);
INSERT INTO Link VALUES (187, 125, 0, 1, 151, 152);
INSERT INTO Link VALUES (188, 190, 0, 1, 152, 153);
INSERT INTO Link VALUES (189, 110, 0, 1, 153, 154);
INSERT INTO Link VALUES (190, 150, 0, 1, 154, 155);
INSERT INTO Link VALUES (191, 115, 0, 1, 155, 156);
INSERT INTO Link VALUES (192, 160, 0, 1, 156, 157);
INSERT INTO Link VALUES (193, 120, 1, 1, 157, 173);
INSERT INTO Link VALUES (194, 150, 0, 1, 181, 182);
INSERT INTO Link VALUES (195, 150, 0, 1, 182, 158);
INSERT INTO Link VALUES (196, 160, 0, 1, 158, 159);
INSERT INTO Link VALUES (197, 160, 0, 1, 159, 160);
INSERT INTO Link VALUES (198, 175, 0, 1, 160, 161);
INSERT INTO Link VALUES (199, 165, 0, 1, 161, 162);
INSERT INTO Link VALUES (200, 145, 0, 1, 162, 163);
INSERT INTO Link VALUES (201, 130, 0, 1, 163, 164);
INSERT INTO Link VALUES (202, 240, 0, 1, 164, 165);
INSERT INTO Link VALUES (203, 160, 0, 1, 165, 166);
INSERT INTO Link VALUES (204, 170, 0, 1, 166, 167);
INSERT INTO Link VALUES (205, 185, 0, 1, 167, 168);
INSERT INTO Link VALUES (206, 140, 0, 1, 168, 169);
INSERT INTO Link VALUES (207, 175, 0, 1, 170, 171);
INSERT INTO Link VALUES (208, 125, 0, 1, 171, 172);
INSERT INTO Link VALUES (209, 295, 0, 1, 173, 174);
INSERT INTO Link VALUES (210, 80, 0, 1, 174, 175);
INSERT INTO Link VALUES (211, 105, 0, 1, 175, 176);
INSERT INTO Link VALUES (212, 115, 0, 1, 176, 177);
INSERT INTO Link VALUES (213, 180, 0, 13, 1, 2);
INSERT INTO Link VALUES (214, 120, 0, 13, 2, 3);
INSERT INTO Link VALUES (215, 120, 0, 13, 3, 4);
INSERT INTO Link VALUES (216, 100, 0, 13, 4, 5);
INSERT INTO Link VALUES (217, 120, 0, 13, 5, 6);
INSERT INTO Link VALUES (218, 80, 0, 13, 6, 7);
INSERT INTO Link VALUES (219, 120, 0, 13, 7, 8);
INSERT INTO Link VALUES (220, 120, 0, 13, 8, 9);
INSERT INTO Link VALUES (221, 180, 1, 13, 9, 19);
INSERT INTO Link VALUES (222, 120, 0, 13, 9, 10);
INSERT INTO Link VALUES (223, 120, 0, 13, 10, 11);
INSERT INTO Link VALUES (224, 120, 0, 13, 12, 13);
INSERT INTO Link VALUES (225, 145, 0, 13, 13, 14);
INSERT INTO Link VALUES (226, 120, 0, 13, 14, 15);
INSERT INTO Link VALUES (227, 150, 0, 13, 15, 16);
INSERT INTO Link VALUES (228, 140, 0, 13, 16, 17);
INSERT INTO Link VALUES (229, 120, 0, 13, 17, 18);
INSERT INTO Link VALUES (230, 85, 0, 13, 18, 19);
INSERT INTO Link VALUES (231, 120, 0, 13, 19, 20);
INSERT INTO Link VALUES (232, 120, 0, 13, 20, 21);
INSERT INTO Link VALUES (233, 150, 0, 13, 21, 22);
INSERT INTO Link VALUES (234, 150, 0, 13, 22, 23);
INSERT INTO Link VALUES (235, 180, 0, 13, 23, 24);
INSERT INTO Link VALUES (236, 150, 0, 13, 24, 25);
INSERT INTO Link VALUES (237, 180, 0, 2, 1, 2);
INSERT INTO Link VALUES (238, 360, 0, 2, 2, 3);
INSERT INTO Link VALUES (239, 120, 0, 2, 3, 4);
INSERT INTO Link VALUES (240, 180, 0, 2, 4, 5);
INSERT INTO Link VALUES (241, 180, 0, 2, 5, 6);
INSERT INTO Link VALUES (242, 180, 0, 2, 6, 7);
INSERT INTO Link VALUES (243, 120, 0, 2, 7, 8);
INSERT INTO Link VALUES (244, 180, 0, 2, 8, 9);
INSERT INTO Link VALUES (245, 120, 0, 2, 9, 10);
INSERT INTO Link VALUES (246, 120, 1, 2, 10, 41);
INSERT INTO Link VALUES (247, 120, 0, 2, 10, 11);
INSERT INTO Link VALUES (248, 120, 0, 2, 11, 12);
INSERT INTO Link VALUES (249, 120, 1, 2, 11, 49);
INSERT INTO Link VALUES (250, 120, 1, 2, 12, 62);
INSERT INTO Link VALUES (251, 120, 0, 2, 12, 13);
INSERT INTO Link VALUES (252, 120, 0, 2, 13, 14);
INSERT INTO Link VALUES (253, 60, 1, 2, 13, 30);
INSERT INTO Link VALUES (254, 180, 0, 2, 14, 15);
INSERT INTO Link VALUES (255, 240, 0, 2, 15, 16);
INSERT INTO Link VALUES (256, 120, 0, 2, 16, 17);
INSERT INTO Link VALUES (257, 180, 0, 2, 17, 18);
INSERT INTO Link VALUES (258, 120, 0, 2, 18, 19);
INSERT INTO Link VALUES (259, 180, 0, 2, 20, 21);
INSERT INTO Link VALUES (260, 120, 0, 2, 21, 22);
INSERT INTO Link VALUES (261, 180, 0, 2, 22, 23);
INSERT INTO Link VALUES (262, 180, 0, 2, 23, 24);
INSERT INTO Link VALUES (263, 180, 0, 2, 24, 25);
INSERT INTO Link VALUES (264, 240, 0, 2, 25, 26);
INSERT INTO Link VALUES (265, 120, 0, 2, 26, 27);
INSERT INTO Link VALUES (266, 240, 0, 2, 27, 28);
INSERT INTO Link VALUES (267, 120, 1, 2, 28, 40);
INSERT INTO Link VALUES (268, 120, 0, 2, 28, 29);
INSERT INTO Link VALUES (269, 180, 1, 2, 29, 61);
INSERT INTO Link VALUES (270, 180, 1, 2, 29, 48);
INSERT INTO Link VALUES (271, 180, 0, 2, 29, 30);
INSERT INTO Link VALUES (272, 120, 0, 2, 30, 31);
INSERT INTO Link VALUES (273, 120, 0, 2, 31, 32);
INSERT INTO Link VALUES (274, 120, 0, 2, 32, 33);
INSERT INTO Link VALUES (275, 120, 0, 2, 33, 34);
INSERT INTO Link VALUES (276, 180, 0, 2, 34, 35);
INSERT INTO Link VALUES (277, 240, 0, 2, 35, 36);
INSERT INTO Link VALUES (278, 180, 0, 2, 36, 37);
INSERT INTO Link VALUES (279, 240, 0, 2, 38, 39);
INSERT INTO Link VALUES (280, 240, 0, 2, 39, 40);
INSERT INTO Link VALUES (281, 180, 0, 2, 40, 41);
INSERT INTO Link VALUES (282, 180, 0, 2, 41, 42);
INSERT INTO Link VALUES (283, 300, 0, 2, 42, 43);
INSERT INTO Link VALUES (284, 120, 1, 2, 42, 51);
INSERT INTO Link VALUES (285, 180, 0, 2, 43, 44);
INSERT INTO Link VALUES (286, 180, 0, 2, 44, 45);
INSERT INTO Link VALUES (287, 180, 0, 2, 45, 46);
INSERT INTO Link VALUES (288, 240, 0, 2, 46, 47);
INSERT INTO Link VALUES (289, 180, 1, 2, 48, 61);
INSERT INTO Link VALUES (290, 240, 0, 2, 48, 49);
INSERT INTO Link VALUES (291, 120, 0, 2, 49, 50);
INSERT INTO Link VALUES (292, 120, 0, 2, 50, 51);
INSERT INTO Link VALUES (293, 180, 0, 2, 51, 52);
INSERT INTO Link VALUES (294, 180, 0, 2, 52, 53);
INSERT INTO Link VALUES (295, 180, 0, 2, 53, 54);
INSERT INTO Link VALUES (296, 120, 0, 2, 54, 55);
INSERT INTO Link VALUES (297, 180, 0, 2, 56, 57);
INSERT INTO Link VALUES (298, 180, 0, 2, 57, 58);
INSERT INTO Link VALUES (299, 240, 0, 2, 58, 59);
INSERT INTO Link VALUES (300, 120, 0, 2, 59, 60);
INSERT INTO Link VALUES (301, 300, 0, 2, 60, 61);
INSERT INTO Link VALUES (302, 240, 0, 2, 61, 62);
INSERT INTO Link VALUES (303, 300, 0, 2, 62, 63);
INSERT INTO Link VALUES (304, 150, 0, 8, 1, 2);
INSERT INTO Link VALUES (305, 175, 0, 8, 2, 3);
INSERT INTO Link VALUES (306, 110, 0, 8, 3, 4);
INSERT INTO Link VALUES (307, 110, 0, 8, 4, 5);
INSERT INTO Link VALUES (308, 190, 0, 8, 5, 6);
INSERT INTO Link VALUES (309, 115, 0, 8, 6, 7);
INSERT INTO Link VALUES (310, 190, 0, 8, 7, 8);
INSERT INTO Link VALUES (311, 115, 0, 8, 8, 9);
INSERT INTO Link VALUES (312, 115, 0, 8, 9, 10);
INSERT INTO Link VALUES (313, 120, 0, 8, 10, 11);
INSERT INTO Link VALUES (314, 180, 1, 8, 10, 34);
INSERT INTO Link VALUES (315, 180, 1, 8, 11, 26);
INSERT INTO Link VALUES (316, 180, 0, 8, 11, 12);
INSERT INTO Link VALUES (317, 110, 0, 8, 12, 13);
INSERT INTO Link VALUES (318, 150, 0, 8, 13, 14);
INSERT INTO Link VALUES (319, 155, 0, 8, 14, 15);
INSERT INTO Link VALUES (320, 120, 0, 8, 15, 16);
INSERT INTO Link VALUES (321, 145, 0, 8, 16, 17);
INSERT INTO Link VALUES (322, 125, 0, 8, 17, 18);
INSERT INTO Link VALUES (323, 130, 0, 8, 19, 20);
INSERT INTO Link VALUES (324, 115, 0, 8, 20, 21);
INSERT INTO Link VALUES (325, 155, 0, 8, 21, 22);
INSERT INTO Link VALUES (326, 170, 0, 8, 22, 23);
INSERT INTO Link VALUES (327, 135, 0, 8, 23, 24);
INSERT INTO Link VALUES (328, 110, 0, 8, 24, 25);
INSERT INTO Link VALUES (329, 130, 0, 8, 25, 26);
INSERT INTO Link VALUES (330, 120, 0, 8, 26, 27);
INSERT INTO Link VALUES (331, 180, 1, 8, 27, 35);
INSERT INTO Link VALUES (332, 120, 0, 8, 27, 28);
INSERT INTO Link VALUES (333, 110, 0, 8, 28, 29);
INSERT INTO Link VALUES (334, 85, 0, 8, 29, 30);
INSERT INTO Link VALUES (335, 130, 0, 8, 31, 32);
INSERT INTO Link VALUES (336, 230, 0, 8, 32, 33);
INSERT INTO Link VALUES (337, 300, 0, 8, 33, 34);
INSERT INTO Link VALUES (338, 120, 0, 8, 34, 35);
INSERT INTO Link VALUES (339, 125, 0, 8, 35, 36);
INSERT INTO Link VALUES (340, 125, 0, 8, 36, 37);
INSERT INTO Link VALUES (341, 110, 0, 8, 37, 38);
INSERT INTO Link VALUES (342, 150, 0, 8, 38, 39);
INSERT INTO Link VALUES (343, 405, 0, 8, 39, 40);
INSERT INTO Link VALUES (344, 105, 0, 8, 40, 41);
INSERT INTO Link VALUES (345, 220, 0, 8, 41, 42);
INSERT INTO Link VALUES (346, 215, 0, 8, 42, 43);
INSERT INTO Link VALUES (347, 120, 0, 8, 43, 44);
INSERT INTO Link VALUES (348, 125, 0, 8, 44, 45);
INSERT INTO Link VALUES (349, 135, 0, 8, 45, 46);
INSERT INTO Link VALUES (350, 180, 0, 9, 1, 2);
INSERT INTO Link VALUES (351, 120, 0, 9, 2, 3);
INSERT INTO Link VALUES (352, 60, 0, 9, 3, 4);
INSERT INTO Link VALUES (353, 120, 0, 9, 4, 5);
INSERT INTO Link VALUES (354, 100, 1, 9, 4, 21);
INSERT INTO Link VALUES (355, 120, 0, 9, 5, 6);
INSERT INTO Link VALUES (356, 150, 1, 9, 6, 28);
INSERT INTO Link VALUES (357, 120, 0, 9, 6, 7);
INSERT INTO Link VALUES (358, 120, 0, 9, 7, 8);
INSERT INTO Link VALUES (359, 120, 0, 9, 8, 9);
INSERT INTO Link VALUES (360, 180, 0, 9, 9, 10);
INSERT INTO Link VALUES (361, 120, 0, 9, 10, 11);
INSERT INTO Link VALUES (362, 120, 0, 9, 11, 12);
INSERT INTO Link VALUES (363, 120, 0, 9, 12, 13);
INSERT INTO Link VALUES (364, 120, 0, 9, 14, 15);
INSERT INTO Link VALUES (365, 120, 0, 9, 15, 16);
INSERT INTO Link VALUES (366, 120, 0, 9, 16, 17);
INSERT INTO Link VALUES (367, 180, 0, 9, 17, 18);
INSERT INTO Link VALUES (368, 120, 0, 9, 18, 19);
INSERT INTO Link VALUES (369, 120, 0, 9, 19, 20);
INSERT INTO Link VALUES (370, 200, 1, 9, 20, 25);
INSERT INTO Link VALUES (371, 120, 0, 9, 20, 21);
INSERT INTO Link VALUES (372, 120, 0, 9, 22, 23);
INSERT INTO Link VALUES (373, 120, 0, 9, 23, 24);
INSERT INTO Link VALUES (374, 120, 0, 9, 24, 25);
INSERT INTO Link VALUES (375, 60, 0, 9, 25, 26);
INSERT INTO Link VALUES (376, 180, 0, 9, 26, 27);
INSERT INTO Link VALUES (377, 120, 0, 9, 27, 28);
INSERT INTO DrawElement VALUES (0, 'line', 0, 335.0, 192.0, -1, -1, -1, 30, 1);
INSERT INTO DrawElement VALUES (1, 'line', 1, 395.0, 252.0, -1, -1, -1, 30, 1);
INSERT INTO DrawElement VALUES (2, 'line', 0, 665.0, 628.0, -1, -1, -1, 41, 1);
INSERT INTO DrawElement VALUES (3, 'line', 1, 665.0, 660.0, -1, -1, -1, 41, 1);
INSERT INTO DrawElement VALUES (4, 'line', 0, 679.0, 464.0, -1, -1, -1, 58, 1);
INSERT INTO DrawElement VALUES (5, 'line', 1, 471.0, 464.0, -1, -1, -1, 58, 1);
INSERT INTO DrawElement VALUES (6, 'line', 0, 425.0, 510.0, -1, -1, -1, 59, 1);
INSERT INTO DrawElement VALUES (7, 'line', 1, 395.0, 510.0, -1, -1, -1, 59, 1);
INSERT INTO DrawElement VALUES (8, 'line', 0, 202.0, 402.0, -1, -1, -1, 65, 1);
INSERT INTO DrawElement VALUES (9, 'line', 1, 132.0, 332.0, -1, -1, -1, 65, 1);
INSERT INTO DrawElement VALUES (10, 'line', 2, 132.0, 295.0, -1, -1, -1, 65, 1);
INSERT INTO DrawElement VALUES (11, 'line', 0, 172.0, 323.0, -1, -1, -1, 81, 1);
INSERT INTO DrawElement VALUES (12, 'line', 1, 221.0, 372.0, -1, -1, -1, 81, 1);
INSERT INTO DrawElement VALUES (13, 'line', 2, 287.0, 372.0, -1, -1, -1, 81, 1);
INSERT INTO DrawElement VALUES (14, 'arc', 0, 500.0, 420.0, 215.0, 137.79999, 113.00001, 87, 1);
INSERT INTO DrawElement VALUES (15, 'arc', 0, 500.0, 420.0, 215.0, 113.00001, 77.899994, 89, 1);
INSERT INTO DrawElement VALUES (16, 'arc', 0, 500.0, 420.0, 215.0, 77.899994, 50.299988, 92, 1);
INSERT INTO DrawElement VALUES (17, 'arc', 0, 500.0, 420.0, 215.0, 50.299988, 32.79998, 94, 1);
INSERT INTO DrawElement VALUES (18, 'arc', 0, 500.0, 420.0, 215.0, 32.79998, 6.399987, 97, 1);
INSERT INTO DrawElement VALUES (19, 'arc', 0, 500.0, 420.0, 215.0, 6.399987, 317.80002, 100, 1);
INSERT INTO DrawElement VALUES (20, 'arc', 0, 500.0, 420.0, 215.0, 317.80002, 296.2, 101, 1);
INSERT INTO DrawElement VALUES (21, 'arc', 0, 500.0, 420.0, 215.0, 296.2, 259.9, 103, 1);
INSERT INTO DrawElement VALUES (22, 'arc', 0, 500.0, 420.0, 215.0, 259.9, 240.80002, 106, 1);
INSERT INTO DrawElement VALUES (23, 'arc', 0, 500.0, 420.0, 215.0, 240.80002, 217.0, 107, 1);
INSERT INTO DrawElement VALUES (24, 'arc', 0, 500.0, 420.0, 215.0, 217.0, 188.79999, 108, 1);
INSERT INTO DrawElement VALUES (25, 'arc', 0, 500.0, 420.0, 215.0, 188.79999, 137.79999, 112, 1);
INSERT INTO DrawElement VALUES (26, 'line', 0, 595.0, 454.0, -1, -1, -1, 124, 1);
INSERT INTO DrawElement VALUES (27, 'line', 1, 558.0, 491.0, -1, -1, -1, 124, 1);
INSERT INTO DrawElement VALUES (28, 'line', 0, 383.0, 666.0, -1, -1, -1, 128, 1);
INSERT INTO DrawElement VALUES (29, 'line', 1, 383.0, 675.0, -1, -1, -1, 128, 1);
INSERT INTO DrawElement VALUES (30, 'line', 0, 295.0, 273.0, -1, -1, -1, 146, 1);
INSERT INTO DrawElement VALUES (31, 'line', 1, 328.0, 306.0, -1, -1, -1, 146, 1);
INSERT INTO DrawElement VALUES (32, 'line', 0, 735.0, 576.0, -1, -1, -1, 152, 1);
INSERT INTO DrawElement VALUES (33, 'line', 1, 776.0, 576.0, -1, -1, -1, 152, 1);
INSERT INTO DrawElement VALUES (34, 'line', 0, 462.0, 223.0, -1, -1, -1, 175, 1);
INSERT INTO DrawElement VALUES (35, 'line', 1, 511.0, 272.0, -1, -1, -1, 175, 1);
INSERT INTO DrawElement VALUES (36, 'line', 0, 168.0, 415.0, -1, -1, -1, 252, 2);
INSERT INTO DrawElement VALUES (37, 'line', 1, 168.0, 440.0, -1, -1, -1, 252, 2);
INSERT INTO DrawElement VALUES (38, 'line', 0, 126.0, 200.0, -1, -1, -1, 280, 2);
INSERT INTO DrawElement VALUES (39, 'line', 1, 146.0, 220.0, -1, -1, -1, 280, 2);
INSERT INTO DrawElement VALUES (40, 'line', 2, 208.0, 220.0, -1, -1, -1, 280, 2);
INSERT INTO DrawElement VALUES (41, 'line', 0, 543.0, 220.0, -1, -1, -1, 282, 2);
INSERT INTO DrawElement VALUES (42, 'line', 1, 558.0, 235.0, -1, -1, -1, 282, 2);
INSERT INTO DrawElement VALUES (43, 'line', 2, 558.0, 275.0, -1, -1, -1, 282, 2);
INSERT INTO DrawElement VALUES (44, 'line', 0, 533.0, 265.0, -1, -1, -1, 292, 2);
INSERT INTO DrawElement VALUES (45, 'line', 1, 558.0, 290.0, -1, -1, -1, 292, 2);
INSERT INTO DrawElement VALUES (46, 'line', 0, 598.0, 330.0, -1, -1, -1, 293, 2);
INSERT INTO DrawElement VALUES (47, 'line', 1, 598.0, 345.0, -1, -1, -1, 293, 2);
INSERT INTO DrawElement VALUES (48, 'line', 0, 168.0, 240.0, -1, -1, -1, 301, 2);
INSERT INTO DrawElement VALUES (49, 'line', 1, 208.0, 280.0, -1, -1, -1, 301, 2);
INSERT INTO DrawElement VALUES (50, 'line', 0, 300.0, 255.0, -1, -1, -1, 312, 8);
INSERT INTO DrawElement VALUES (51, 'line', 1, 370.0, 185.0, -1, -1, -1, 312, 8);
INSERT INTO DrawElement VALUES (52, 'line', 0, 520.0, 265.0, -1, -1, -1, 318, 8);
INSERT INTO DrawElement VALUES (53, 'line', 1, 570.0, 265.0, -1, -1, -1, 318, 8);
INSERT INTO DrawElement VALUES (54, 'line', 2, 600.0, 235.0, -1, -1, -1, 318, 8);
INSERT INTO DrawElement VALUES (55, 'line', 0, 370.0, 200.0, -1, -1, -1, 338, 8);
INSERT INTO DrawElement VALUES (56, 'line', 1, 440.0, 270.0, -1, -1, -1, 338, 8);
INSERT INTO DrawElement VALUES (57, 'line', 0, 550.0, 380.0, -1, -1, -1, 343, 8);
INSERT INTO DrawElement VALUES (58, 'line', 1, 600.0, 380.0, -1, -1, -1, 343, 8);
INSERT INTO DrawElement VALUES (59, 'line', 2, 630.0, 350.0, -1, -1, -1, 343, 8);
INSERT INTO Transfer VALUES (0, 1);
INSERT INTO Transfer VALUES (1, 1);
INSERT INTO Transfer VALUES (2, 1);
INSERT INTO Transfer VALUES (3, 1);
INSERT INTO Transfer VALUES (4, 1);
INSERT INTO Transfer VALUES (5, 1);
INSERT INTO Transfer VALUES (6, 1);
INSERT INTO Transfer VALUES (7, 1);
INSERT INTO Transfer VALUES (8, 1);
INSERT INTO Transfer VALUES (9, 1);
INSERT INTO Transfer VALUES (10, 1);
INSERT INTO Transfer VALUES (11, 1);
INSERT INTO Transfer VALUES (12, 1);
INSERT INTO Transfer VALUES (13, 1);
INSERT INTO Transfer VALUES (14, 1);
INSERT INTO Transfer VALUES (15, 1);
INSERT INTO Transfer VALUES (16, 1);
INSERT INTO Transfer VALUES (17, 1);
INSERT INTO Transfer VALUES (18, 1);
INSERT INTO Transfer VALUES (19, 1);
INSERT INTO Transfer VALUES (20, 1);
INSERT INTO Transfer VALUES (21, 1);
INSERT INTO Transfer VALUES (22, 1);
INSERT INTO Transfer VALUES (23, 1);
INSERT INTO Transfer VALUES (24, 1);
INSERT INTO Transfer VALUES (25, 13);
INSERT INTO Transfer VALUES (26, 2);
INSERT INTO Transfer VALUES (27, 2);
INSERT INTO Transfer VALUES (28, 2);
INSERT INTO Transfer VALUES (29, 2);
INSERT INTO Transfer VALUES (30, 2);
INSERT INTO Transfer VALUES (31, 2);
INSERT INTO Transfer VALUES (32, 2);
INSERT INTO Transfer VALUES (33, 8);
INSERT INTO Transfer VALUES (34, 8);
INSERT INTO Transfer VALUES (35, 8);
INSERT INTO Transfer VALUES (36, 9);
INSERT INTO Transfer VALUES (37, 9);
INSERT INTO Transfer VALUES (38, 9);
INSERT INTO StationForTransfer VALUES (0, 0, 72, 0, 1);
INSERT INTO StationForTransfer VALUES (1, 0, 95, 1, 1);
INSERT INTO StationForTransfer VALUES (2, 1, 142, 0, 1);
INSERT INTO StationForTransfer VALUES (3, 1, 158, 1, 1);
INSERT INTO StationForTransfer VALUES (4, 2, 141, 0, 1);
INSERT INTO StationForTransfer VALUES (5, 2, 79, 1, 1);
INSERT INTO StationForTransfer VALUES (6, 3, 92, 0, 1);
INSERT INTO StationForTransfer VALUES (7, 3, 8, 1, 1);
INSERT INTO StationForTransfer VALUES (8, 3, 159, 2, 1);
INSERT INTO StationForTransfer VALUES (9, 4, 131, 0, 1);
INSERT INTO StationForTransfer VALUES (10, 4, 119, 1, 1);
INSERT INTO StationForTransfer VALUES (11, 4, 75, 2, 1);
INSERT INTO StationForTransfer VALUES (12, 5, 94, 0, 1);
INSERT INTO StationForTransfer VALUES (13, 5, 132, 1, 1);
INSERT INTO StationForTransfer VALUES (14, 5, 30, 2, 1);
INSERT INTO StationForTransfer VALUES (15, 6, 65, 0, 1);
INSERT INTO StationForTransfer VALUES (16, 6, 82, 1, 1);
INSERT INTO StationForTransfer VALUES (17, 6, 51, 2, 1);
INSERT INTO StationForTransfer VALUES (18, 7, 90, 0, 1);
INSERT INTO StationForTransfer VALUES (19, 7, 78, 1, 1);
INSERT INTO StationForTransfer VALUES (20, 8, 81, 0, 1);
INSERT INTO StationForTransfer VALUES (21, 8, 115, 1, 1);
INSERT INTO StationForTransfer VALUES (22, 9, 71, 0, 1);
INSERT INTO StationForTransfer VALUES (23, 9, 13, 1, 1);
INSERT INTO StationForTransfer VALUES (24, 10, 117, 0, 1);
INSERT INTO StationForTransfer VALUES (25, 10, 9, 1, 1);
INSERT INTO StationForTransfer VALUES (26, 11, 172, 0, 1);
INSERT INTO StationForTransfer VALUES (27, 11, 151, 1, 1);
INSERT INTO StationForTransfer VALUES (28, 12, 157, 0, 1);
INSERT INTO StationForTransfer VALUES (29, 12, 173, 1, 1);
INSERT INTO StationForTransfer VALUES (30, 13, 74, 0, 1);
INSERT INTO StationForTransfer VALUES (31, 13, 31, 1, 1);
INSERT INTO StationForTransfer VALUES (32, 14, 6, 0, 1);
INSERT INTO StationForTransfer VALUES (33, 14, 77, 1, 1);
INSERT INTO StationForTransfer VALUES (34, 15, 58, 0, 1);
INSERT INTO StationForTransfer VALUES (35, 15, 54, 1, 1);
INSERT INTO StationForTransfer VALUES (36, 16, 130, 0, 1);
INSERT INTO StationForTransfer VALUES (37, 16, 161, 1, 1);
INSERT INTO StationForTransfer VALUES (38, 17, 28, 0, 1);
INSERT INTO StationForTransfer VALUES (39, 17, 116, 1, 1);
INSERT INTO StationForTransfer VALUES (40, 17, 143, 2, 1);
INSERT INTO StationForTransfer VALUES (41, 18, 68, 0, 1);
INSERT INTO StationForTransfer VALUES (42, 18, 144, 1, 1);
INSERT INTO StationForTransfer VALUES (43, 18, 49, 2, 1);
INSERT INTO StationForTransfer VALUES (44, 18, 11, 3, 1);
INSERT INTO StationForTransfer VALUES (45, 19, 34, 0, 1);
INSERT INTO StationForTransfer VALUES (46, 19, 170, 1, 1);
INSERT INTO StationForTransfer VALUES (47, 20, 118, 0, 1);
INSERT INTO StationForTransfer VALUES (48, 20, 93, 1, 1);
INSERT INTO StationForTransfer VALUES (49, 21, 162, 0, 1);
INSERT INTO StationForTransfer VALUES (50, 21, 120, 1, 1);
INSERT INTO StationForTransfer VALUES (51, 22, 29, 0, 1);
INSERT INTO StationForTransfer VALUES (52, 22, 10, 1, 1);
INSERT INTO StationForTransfer VALUES (53, 22, 48, 2, 1);
INSERT INTO StationForTransfer VALUES (54, 23, 47, 0, 1);
INSERT INTO StationForTransfer VALUES (55, 23, 76, 1, 1);
INSERT INTO StationForTransfer VALUES (56, 23, 160, 2, 1);
INSERT INTO StationForTransfer VALUES (57, 24, 73, 0, 1);
INSERT INTO StationForTransfer VALUES (58, 24, 146, 1, 1);
INSERT INTO StationForTransfer VALUES (59, 25, 19, 0, 13);
INSERT INTO StationForTransfer VALUES (60, 25, 9, 1, 13);
INSERT INTO StationForTransfer VALUES (61, 26, 29, 0, 2);
INSERT INTO StationForTransfer VALUES (62, 26, 48, 1, 2);
INSERT INTO StationForTransfer VALUES (63, 26, 61, 2, 2);
INSERT INTO StationForTransfer VALUES (64, 27, 12, 0, 2);
INSERT INTO StationForTransfer VALUES (65, 27, 62, 1, 2);
INSERT INTO StationForTransfer VALUES (66, 28, 42, 0, 2);
INSERT INTO StationForTransfer VALUES (67, 28, 51, 1, 2);
INSERT INTO StationForTransfer VALUES (68, 29, 11, 0, 2);
INSERT INTO StationForTransfer VALUES (69, 29, 49, 1, 2);
INSERT INTO StationForTransfer VALUES (70, 30, 28, 0, 2);
INSERT INTO StationForTransfer VALUES (71, 30, 40, 1, 2);
INSERT INTO StationForTransfer VALUES (72, 31, 10, 0, 2);
INSERT INTO StationForTransfer VALUES (73, 31, 41, 1, 2);
INSERT INTO StationForTransfer VALUES (74, 32, 13, 0, 2);
INSERT INTO StationForTransfer VALUES (75, 32, 30, 1, 2);
INSERT INTO StationForTransfer VALUES (76, 33, 34, 0, 8);
INSERT INTO StationForTransfer VALUES (77, 33, 10, 1, 8);
INSERT INTO StationForTransfer VALUES (78, 34, 35, 0, 8);
INSERT INTO StationForTransfer VALUES (79, 34, 27, 1, 8);
INSERT INTO StationForTransfer VALUES (80, 35, 26, 0, 8);
INSERT INTO StationForTransfer VALUES (81, 35, 11, 1, 8);
INSERT INTO StationForTransfer VALUES (82, 36, 21, 0, 9);
INSERT INTO StationForTransfer VALUES (83, 36, 4, 1, 9);
INSERT INTO StationForTransfer VALUES (84, 37, 20, 0, 9);
INSERT INTO StationForTransfer VALUES (85, 37, 25, 1, 9);
INSERT INTO StationForTransfer VALUES (86, 38, 28, 0, 9);
INSERT INTO StationForTransfer VALUES (87, 38, 6, 1, 9);
INSERT INTO String VALUES ( 0, 1, 'ru', "Moscow", 1 );
INSERT INTO String VALUES ( 0, 1, 'en', "Moscow", 1 );
INSERT INTO String VALUES ( 1, 1, 'ru', "Сокольническая линия", 1 );
INSERT INTO String VALUES ( 1, 2, 'ru', "Замоскворецкая линия", 1 );
INSERT INTO String VALUES ( 1, 3, 'ru', "Арбатско-Покровская линия", 1 );
INSERT INTO String VALUES ( 1, 4, 'ru', "Филевская линия", 1 );
INSERT INTO String VALUES ( 1, 5, 'ru', "Кольцевая линия", 1 );
INSERT INTO String VALUES ( 1, 6, 'ru', "Калужско-Рижская линия", 1 );
INSERT INTO String VALUES ( 1, 7, 'ru', "Таганско-Краснопресненская линия", 1 );
INSERT INTO String VALUES ( 1, 8, 'ru', "Калининская линия", 1 );
INSERT INTO String VALUES ( 1, 9, 'ru', "Серпуховско-Тимирязевская линия", 1 );
INSERT INTO String VALUES ( 1, 10, 'ru', "Люблинская линия", 1 );
INSERT INTO String VALUES ( 1, 11, 'ru', "Каховская линия", 1 );
INSERT INTO String VALUES ( 1, 12, 'ru', "Бутовская линия", 1 );
INSERT INTO String VALUES ( 1, 1, 'en', "Sokolnicheskaya", 1 );
INSERT INTO String VALUES ( 1, 2, 'en', "Zamoskvoretskaya", 1 );
INSERT INTO String VALUES ( 1, 3, 'en', "Arbatsko-Pokrovskaya", 1 );
INSERT INTO String VALUES ( 1, 4, 'en', "Filyovskaya", 1 );
INSERT INTO String VALUES ( 1, 5, 'en', "Koltsevaya", 1 );
INSERT INTO String VALUES ( 1, 6, 'en', "Kaluzhsko-Rizhskaya", 1 );
INSERT INTO String VALUES ( 1, 7, 'en', "Tagansko-Krasnopresnenskaya", 1 );
INSERT INTO String VALUES ( 1, 8, 'en', "Kalininskaya", 1 );
INSERT INTO String VALUES ( 1, 9, 'en', "Serpukhovsko-Timiryazevskaya", 1 );
INSERT INTO String VALUES ( 1, 10, 'en', "Lyublinskaya", 1 );
INSERT INTO String VALUES ( 1, 11, 'en', "Kakhovskaya", 1 );
INSERT INTO String VALUES ( 1, 12, 'en', "Butovskaya Light Metro", 1 );
INSERT INTO String VALUES ( 2, 1, 'ru', "Улица Подбельского", 1 );
INSERT INTO String VALUES ( 2, 2, 'ru', "Черкизовская", 1 );
INSERT INTO String VALUES ( 2, 3, 'ru', "Преображенская площадь", 1 );
INSERT INTO String VALUES ( 2, 4, 'ru', "Сокольники", 1 );
INSERT INTO String VALUES ( 2, 5, 'ru', "Красносельская", 1 );
INSERT INTO String VALUES ( 2, 6, 'ru', "Комсомольская", 1 );
INSERT INTO String VALUES ( 2, 7, 'ru', "Красные ворота", 1 );
INSERT INTO String VALUES ( 2, 8, 'ru', "Чистые пруды", 1 );
INSERT INTO String VALUES ( 2, 9, 'ru', "Лубянка", 1 );
INSERT INTO String VALUES ( 2, 10, 'ru', "Охотный ряд", 1 );
INSERT INTO String VALUES ( 2, 11, 'ru', "Библиотека имени Ленина", 1 );
INSERT INTO String VALUES ( 2, 12, 'ru', "Кропоткинская", 1 );
INSERT INTO String VALUES ( 2, 13, 'ru', "Парк культуры", 1 );
INSERT INTO String VALUES ( 2, 14, 'ru', "Фрунзенская", 1 );
INSERT INTO String VALUES ( 2, 15, 'ru', "Спортивная", 1 );
INSERT INTO String VALUES ( 2, 16, 'ru', "Воробьёвы горы", 1 );
INSERT INTO String VALUES ( 2, 17, 'ru', "Университет", 1 );
INSERT INTO String VALUES ( 2, 18, 'ru', "Проспект Вернадского", 1 );
INSERT INTO String VALUES ( 2, 19, 'ru', "Юго-Западная", 1 );
INSERT INTO String VALUES ( 2, 20, 'ru', "Речной вокзал", 1 );
INSERT INTO String VALUES ( 2, 21, 'ru', "Водный стадион", 1 );
INSERT INTO String VALUES ( 2, 22, 'ru', "Войковская", 1 );
INSERT INTO String VALUES ( 2, 23, 'ru', "Сокол", 1 );
INSERT INTO String VALUES ( 2, 24, 'ru', "Аэропорт", 1 );
INSERT INTO String VALUES ( 2, 25, 'ru', "Динамо", 1 );
INSERT INTO String VALUES ( 2, 26, 'ru', "Белорусская", 1 );
INSERT INTO String VALUES ( 2, 27, 'ru', "Маяковская", 1 );
INSERT INTO String VALUES ( 2, 28, 'ru', "Тверская", 1 );
INSERT INTO String VALUES ( 2, 29, 'ru', "Театральная", 1 );
INSERT INTO String VALUES ( 2, 30, 'ru', "Новокузнецкая", 1 );
INSERT INTO String VALUES ( 2, 31, 'ru', "Павелецкая", 1 );
INSERT INTO String VALUES ( 2, 32, 'ru', "Автозаводская", 1 );
INSERT INTO String VALUES ( 2, 33, 'ru', "Коломенская", 1 );
INSERT INTO String VALUES ( 2, 34, 'ru', "Каширская", 1 );
INSERT INTO String VALUES ( 2, 35, 'ru', "Кантемировская", 1 );
INSERT INTO String VALUES ( 2, 36, 'ru', "Царицыно", 1 );
INSERT INTO String VALUES ( 2, 37, 'ru', "Орехово", 1 );
INSERT INTO String VALUES ( 2, 38, 'ru', "Домодедовская", 1 );
INSERT INTO String VALUES ( 2, 39, 'ru', "Красногвардейская", 1 );
INSERT INTO String VALUES ( 2, 40, 'ru', "Щёлковская", 1 );
INSERT INTO String VALUES ( 2, 41, 'ru', "Первомайская", 1 );
INSERT INTO String VALUES ( 2, 42, 'ru', "Измайловская", 1 );
INSERT INTO String VALUES ( 2, 43, 'ru', "Партизанская", 1 );
INSERT INTO String VALUES ( 2, 44, 'ru', "Семёновская", 1 );
INSERT INTO String VALUES ( 2, 45, 'ru', "Электрозаводская", 1 );
INSERT INTO String VALUES ( 2, 46, 'ru', "Бауманская", 1 );
INSERT INTO String VALUES ( 2, 47, 'ru', "Курская", 1 );
INSERT INTO String VALUES ( 2, 48, 'ru', "Площадь Революции", 1 );
INSERT INTO String VALUES ( 3, 48, 'ru', "Площадь
Революции", 1 );
INSERT INTO String VALUES ( 2, 49, 'ru', "Арбатская", 1 );
INSERT INTO String VALUES ( 2, 50, 'ru', "Смоленская", 1 );
INSERT INTO String VALUES ( 2, 51, 'ru', "Киевская", 1 );
INSERT INTO String VALUES ( 2, 52, 'ru', "Парк Победы", 1 );
INSERT INTO String VALUES ( 2, 53, 'ru', "Славянский бульвар", 1 );
INSERT INTO String VALUES ( 2, 54, 'ru', "Кунцевская", 1 );
INSERT INTO String VALUES ( 2, 55, 'ru', "Молодёжная", 1 );
INSERT INTO String VALUES ( 2, 56, 'ru', "Крылатское", 1 );
INSERT INTO String VALUES ( 2, 57, 'ru', "Строгино", 1 );
INSERT INTO String VALUES ( 2, 178, 'ru', "Мякинино", 1 );
INSERT INTO String VALUES ( 2, 179, 'ru', "Волоколамская", 1 );
INSERT INTO String VALUES ( 2, 180, 'ru', "Митино", 1 );
INSERT INTO String VALUES ( 2, 59, 'ru', "Пионерская", 1 );
INSERT INTO String VALUES ( 2, 60, 'ru', "Филёвский парк", 1 );
INSERT INTO String VALUES ( 2, 61, 'ru', "Багратионовская", 1 );
INSERT INTO String VALUES ( 2, 62, 'ru', "Фили", 1 );
INSERT INTO String VALUES ( 2, 63, 'ru', "Кутузовская", 1 );
INSERT INTO String VALUES ( 2, 64, 'ru', "Студенческая", 1 );
INSERT INTO String VALUES ( 2, 66, 'ru', "Смоленская", 1 );
INSERT INTO String VALUES ( 2, 67, 'ru', "Арбатская", 1 );
INSERT INTO String VALUES ( 2, 68, 'ru', "Александровский сад", 1 );
INSERT INTO String VALUES ( 2, 69, 'ru', "Выставочная", 1 );
INSERT INTO String VALUES ( 2, 70, 'ru', "Международная", 1 );
INSERT INTO String VALUES ( 2, 72, 'ru', "Октябрьская", 1 );
INSERT INTO String VALUES ( 2, 73, 'ru', "Добрынинская", 1 );
INSERT INTO String VALUES ( 2, 75, 'ru', "Таганская", 1 );
INSERT INTO String VALUES ( 2, 78, 'ru', "Проспект Мира", 1 );
INSERT INTO String VALUES ( 2, 79, 'ru', "Новослободская", 1 );
INSERT INTO String VALUES ( 2, 80, 'ru', "Белорусская", 1 );
INSERT INTO String VALUES ( 2, 81, 'ru', "Краснопресненская", 1 );
INSERT INTO String VALUES ( 2, 83, 'ru', "Медведково", 1 );
INSERT INTO String VALUES ( 2, 84, 'ru', "Бабушкинская", 1 );
INSERT INTO String VALUES ( 2, 85, 'ru', "Свиблово", 1 );
INSERT INTO String VALUES ( 2, 86, 'ru', "Ботанический сад", 1 );
INSERT INTO String VALUES ( 2, 87, 'ru', "ВДНХ", 1 );
INSERT INTO String VALUES ( 2, 88, 'ru', "Алексеевская", 1 );
INSERT INTO String VALUES ( 2, 89, 'ru', "Рижская", 1 );
INSERT INTO String VALUES ( 2, 91, 'ru', "Сухаревская", 1 );
INSERT INTO String VALUES ( 2, 92, 'ru', "Тургеневская", 1 );
INSERT INTO String VALUES ( 2, 93, 'ru', "Китай-город", 1 );
INSERT INTO String VALUES ( 2, 94, 'ru', "Третьяковская", 1 );
INSERT INTO String VALUES ( 2, 96, 'ru', "Шаболовская", 1 );
INSERT INTO String VALUES ( 2, 97, 'ru', "Ленинский проспект", 1 );
INSERT INTO String VALUES ( 2, 98, 'ru', "Академическая", 1 );
INSERT INTO String VALUES ( 2, 99, 'ru', "Профсоюзная", 1 );
INSERT INTO String VALUES ( 2, 100, 'ru', "Новые Черёмушки", 1 );
INSERT INTO String VALUES ( 2, 101, 'ru', "Калужская", 1 );
INSERT INTO String VALUES ( 2, 102, 'ru', "Беляево", 1 );
INSERT INTO String VALUES ( 2, 103, 'ru', "Коньково", 1 );
INSERT INTO String VALUES ( 2, 104, 'ru', "Теплый Стан", 1 );
INSERT INTO String VALUES ( 2, 105, 'ru', "Ясенево", 1 );
INSERT INTO String VALUES ( 2, 106, 'ru', "Новоясеневская", 1 );
INSERT INTO String VALUES ( 2, 107, 'ru', "Планерная", 1 );
INSERT INTO String VALUES ( 2, 108, 'ru', "Сходненская", 1 );
INSERT INTO String VALUES ( 2, 109, 'ru', "Тушинская", 1 );
INSERT INTO String VALUES ( 2, 110, 'ru', "Щукинская", 1 );
INSERT INTO String VALUES ( 2, 111, 'ru', "Октябрьское поле", 1 );
INSERT INTO String VALUES ( 2, 112, 'ru', "Полежаевская", 1 );
INSERT INTO String VALUES ( 2, 113, 'ru', "Беговая", 1 );
INSERT INTO String VALUES ( 2, 114, 'ru', "Улица 1905 года", 1 );
INSERT INTO String VALUES ( 2, 115, 'ru', "Баррикадная", 1 );
INSERT INTO String VALUES ( 2, 116, 'ru', "Пушкинская", 1 );
INSERT INTO String VALUES ( 2, 117, 'ru', "Кузнецкий мост", 1 );
INSERT INTO String VALUES ( 2, 120, 'ru', "Пролетарская", 1 );
INSERT INTO String VALUES ( 2, 121, 'ru', "Волгоградский проспект", 1 );
INSERT INTO String VALUES ( 2, 122, 'ru', "Текстильщики", 1 );
INSERT INTO String VALUES ( 2, 123, 'ru', "Кузьминки", 1 );
INSERT INTO String VALUES ( 2, 124, 'ru', "Рязанский проспект", 1 );
INSERT INTO String VALUES ( 2, 125, 'ru', "Выхино", 1 );
INSERT INTO String VALUES ( 2, 126, 'ru', "Новогиреево", 1 );
INSERT INTO String VALUES ( 2, 127, 'ru', "Перово", 1 );
INSERT INTO String VALUES ( 2, 128, 'ru', "Шоссе Энтузиастов", 1 );
INSERT INTO String VALUES ( 2, 129, 'ru', "Авиамоторная", 1 );
INSERT INTO String VALUES ( 2, 130, 'ru', "Площадь Ильича", 1 );
INSERT INTO String VALUES ( 2, 131, 'ru', "Марксистская", 1 );
INSERT INTO String VALUES ( 2, 133, 'ru', "Алтуфьево", 1 );
INSERT INTO String VALUES ( 2, 134, 'ru', "Бибирево", 1 );
INSERT INTO String VALUES ( 2, 135, 'ru', "Отрадное", 1 );
INSERT INTO String VALUES ( 2, 136, 'ru', "Владыкино", 1 );
INSERT INTO String VALUES ( 2, 137, 'ru', "Петровско-Разумовская", 1 );
INSERT INTO String VALUES ( 3, 137, 'ru', "Петровско-
Разумовская", 1 );
INSERT INTO String VALUES ( 2, 138, 'ru', "Тимирязевская", 1 );
INSERT INTO String VALUES ( 2, 139, 'ru', "Дмитровская", 1 );
INSERT INTO String VALUES ( 2, 140, 'ru', "Савёловская", 1 );
INSERT INTO String VALUES ( 2, 141, 'ru', "Менделеевская", 1 );
INSERT INTO String VALUES ( 2, 142, 'ru', "Цветной бульвар", 1 );
INSERT INTO String VALUES ( 2, 143, 'ru', "Чеховская", 1 );
INSERT INTO String VALUES ( 2, 144, 'ru', "Боровицкая", 1 );
INSERT INTO String VALUES ( 2, 145, 'ru', "Полянка", 1 );
INSERT INTO String VALUES ( 2, 146, 'ru', "Серпуховская", 1 );
INSERT INTO String VALUES ( 2, 147, 'ru', "Тульская", 1 );
INSERT INTO String VALUES ( 2, 148, 'ru', "Нагатинская", 1 );
INSERT INTO String VALUES ( 2, 149, 'ru', "Нагорная", 1 );
INSERT INTO String VALUES ( 2, 150, 'ru', "Нахимовский проспект", 1 );
INSERT INTO String VALUES ( 2, 151, 'ru', "Севастопольская", 1 );
INSERT INTO String VALUES ( 2, 152, 'ru', "Чертановская", 1 );
INSERT INTO String VALUES ( 2, 153, 'ru', "Южная", 1 );
INSERT INTO String VALUES ( 2, 154, 'ru', "Пражская", 1 );
INSERT INTO String VALUES ( 2, 155, 'ru', "Ул. Академика Янгеля", 1 );
INSERT INTO String VALUES ( 2, 156, 'ru', "Аннино", 1 );
INSERT INTO String VALUES ( 2, 157, 'ru', "Бульвар Дмитрия Донского", 1 );
INSERT INTO String VALUES ( 2, 181, 'ru', "Марьина Роща", 1 );
INSERT INTO String VALUES ( 2, 182, 'ru', "Достоевская", 1 );
INSERT INTO String VALUES ( 2, 158, 'ru', "Трубная", 1 );
INSERT INTO String VALUES ( 2, 159, 'ru', "Сретенский бульвар", 1 );
INSERT INTO String VALUES ( 2, 160, 'ru', "Чкаловская", 1 );
INSERT INTO String VALUES ( 2, 161, 'ru', "Римская", 1 );
INSERT INTO String VALUES ( 2, 162, 'ru', "Крестьянская застава", 1 );
INSERT INTO String VALUES ( 2, 163, 'ru', "Дубровка", 1 );
INSERT INTO String VALUES ( 2, 164, 'ru', "Кожуховская", 1 );
INSERT INTO String VALUES ( 2, 165, 'ru', "Печатники", 1 );
INSERT INTO String VALUES ( 2, 166, 'ru', "Волжская", 1 );
INSERT INTO String VALUES ( 2, 167, 'ru', "Люблино", 1 );
INSERT INTO String VALUES ( 2, 168, 'ru', "Братиславская", 1 );
INSERT INTO String VALUES ( 2, 169, 'ru', "Марьино", 1 );
INSERT INTO String VALUES ( 2, 171, 'ru', "Варшавская", 1 );
INSERT INTO String VALUES ( 2, 172, 'ru', "Каховская", 1 );
INSERT INTO String VALUES ( 2, 173, 'ru', "Ул. Старокачаловская", 1 );
INSERT INTO String VALUES ( 2, 174, 'ru', "Ул. Скобелевская", 1 );
INSERT INTO String VALUES ( 2, 175, 'ru', "Бульвар Адмирала Ушакова", 1 );
INSERT INTO String VALUES ( 2, 176, 'ru', "Ул. Горчакова", 1 );
INSERT INTO String VALUES ( 2, 177, 'ru', "Бунинская Аллея", 1 );
INSERT INTO String VALUES ( 2, 1, 'en', "Ulitsa Podbelskogo", 1 );
INSERT INTO String VALUES ( 2, 2, 'en', "Cherkizovskaya", 1 );
INSERT INTO String VALUES ( 2, 3, 'en', "Preobrazhenskaya Ploshchad", 1 );
INSERT INTO String VALUES ( 2, 4, 'en', "Sokolniki", 1 );
INSERT INTO String VALUES ( 2, 5, 'en', "Krasnoselskaya", 1 );
INSERT INTO String VALUES ( 2, 6, 'en', "Komsomolskaya", 1 );
INSERT INTO String VALUES ( 2, 7, 'en', "Krasniye Vorota", 1 );
INSERT INTO String VALUES ( 2, 8, 'en', "Chistiye Prudy", 1 );
INSERT INTO String VALUES ( 2, 9, 'en', "Lubyanka", 1 );
INSERT INTO String VALUES ( 2, 10, 'en', "Okhotny Ryad", 1 );
INSERT INTO String VALUES ( 2, 11, 'en', "Biblioteka Imeni Lenina", 1 );
INSERT INTO String VALUES ( 2, 12, 'en', "Kropotkinskaya", 1 );
INSERT INTO String VALUES ( 2, 13, 'en', "Park Kultury", 1 );
INSERT INTO String VALUES ( 2, 14, 'en', "Frunzenskaya", 1 );
INSERT INTO String VALUES ( 2, 15, 'en', "Sportivnaya", 1 );
INSERT INTO String VALUES ( 2, 16, 'en', "Vorobyovy Gory", 1 );
INSERT INTO String VALUES ( 2, 17, 'en', "Universitet", 1 );
INSERT INTO String VALUES ( 2, 18, 'en', "Prospekt Vernadskogo", 1 );
INSERT INTO String VALUES ( 2, 19, 'en', "Yugo-Zapadnaya", 1 );
INSERT INTO String VALUES ( 2, 20, 'en', "Rechnoy Vokzal", 1 );
INSERT INTO String VALUES ( 2, 21, 'en', "Vodny Stadion", 1 );
INSERT INTO String VALUES ( 2, 22, 'en', "Voykovskaya", 1 );
INSERT INTO String VALUES ( 2, 23, 'en', "Sokol", 1 );
INSERT INTO String VALUES ( 2, 24, 'en', "Aeroport", 1 );
INSERT INTO String VALUES ( 2, 25, 'en', "Dinamo", 1 );
INSERT INTO String VALUES ( 2, 26, 'en', "Belorusskaya", 1 );
INSERT INTO String VALUES ( 2, 27, 'en', "Mayakovskaya", 1 );
INSERT INTO String VALUES ( 2, 28, 'en', "Tverskaya", 1 );
INSERT INTO String VALUES ( 2, 29, 'en', "Teatralnaya", 1 );
INSERT INTO String VALUES ( 2, 30, 'en', "Novokuznetskaya", 1 );
INSERT INTO String VALUES ( 2, 31, 'en', "Paveletskaya", 1 );
INSERT INTO String VALUES ( 2, 32, 'en', "Avtozavodskaya", 1 );
INSERT INTO String VALUES ( 2, 33, 'en', "Kolomenskaya", 1 );
INSERT INTO String VALUES ( 2, 34, 'en', "Kashirskaya", 1 );
INSERT INTO String VALUES ( 2, 35, 'en', "Kantemirovskaya", 1 );
INSERT INTO String VALUES ( 2, 36, 'en', "Tsaritsyno", 1 );
INSERT INTO String VALUES ( 2, 37, 'en', "Orekhovo", 1 );
INSERT INTO String VALUES ( 2, 38, 'en', "Domodedovskaya", 1 );
INSERT INTO String VALUES ( 2, 39, 'en', "Krasnogvardeyskaya", 1 );
INSERT INTO String VALUES ( 2, 40, 'en', "Shchyolkovskaya", 1 );
INSERT INTO String VALUES ( 2, 41, 'en', "Pervomayskaya", 1 );
INSERT INTO String VALUES ( 2, 42, 'en', "Izmaylovskaya", 1 );
INSERT INTO String VALUES ( 2, 43, 'en', "Partizanskaya", 1 );
INSERT INTO String VALUES ( 2, 44, 'en', "Semyonovskaya", 1 );
INSERT INTO String VALUES ( 2, 45, 'en', "Elektrozavodskaya", 1 );
INSERT INTO String VALUES ( 2, 46, 'en', "Baumanskaya", 1 );
INSERT INTO String VALUES ( 2, 47, 'en', "Kurskaya", 1 );
INSERT INTO String VALUES ( 2, 48, 'en', "Ploshchad Revolyutsii", 1 );
INSERT INTO String VALUES ( 2, 49, 'en', "Arbatskaya", 1 );
INSERT INTO String VALUES ( 2, 50, 'en', "Smolenskaya", 1 );
INSERT INTO String VALUES ( 2, 51, 'en', "Kiyevskaya", 1 );
INSERT INTO String VALUES ( 2, 52, 'en', "Park Pobedy", 1 );
INSERT INTO String VALUES ( 2, 53, 'en', "Slavyansky Bulvar", 1 );
INSERT INTO String VALUES ( 2, 54, 'en', "Kuntsevskaya", 1 );
INSERT INTO String VALUES ( 2, 55, 'en', "Molodyozhnaya", 1 );
INSERT INTO String VALUES ( 2, 56, 'en', "Krylatskoye", 1 );
INSERT INTO String VALUES ( 2, 57, 'en', "Strogino", 1 );
INSERT INTO String VALUES ( 2, 178, 'en', "Myakinino", 1 );
INSERT INTO String VALUES ( 2, 179, 'en', "Volokolamskaya", 1 );
INSERT INTO String VALUES ( 2, 180, 'en', "Mitino", 1 );
INSERT INTO String VALUES ( 2, 59, 'en', "Pionerskaya", 1 );
INSERT INTO String VALUES ( 2, 60, 'en', "Filyovsky Park", 1 );
INSERT INTO String VALUES ( 2, 61, 'en', "Bagrationovskaya", 1 );
INSERT INTO String VALUES ( 2, 62, 'en', "Fili", 1 );
INSERT INTO String VALUES ( 2, 63, 'en', "Kutuzovskaya", 1 );
INSERT INTO String VALUES ( 2, 64, 'en', "Studencheskaya", 1 );
INSERT INTO String VALUES ( 2, 66, 'en', "Smolenskaya", 1 );
INSERT INTO String VALUES ( 2, 67, 'en', "Arbatskaya", 1 );
INSERT INTO String VALUES ( 2, 68, 'en', "Alexandrovsky Sad", 1 );
INSERT INTO String VALUES ( 2, 69, 'en', "Vystavochnaya", 1 );
INSERT INTO String VALUES ( 2, 70, 'en', "Mezhdunarodnaya", 1 );
INSERT INTO String VALUES ( 2, 72, 'en', "Oktyabrskaya", 1 );
INSERT INTO String VALUES ( 2, 73, 'en', "Dobryninskaya", 1 );
INSERT INTO String VALUES ( 2, 75, 'en', "Taganskaya", 1 );
INSERT INTO String VALUES ( 2, 78, 'en', "Prospekt Mira", 1 );
INSERT INTO String VALUES ( 2, 79, 'en', "Novoslobodskaya", 1 );
INSERT INTO String VALUES ( 2, 80, 'en', "Belorusskaya", 1 );
INSERT INTO String VALUES ( 2, 81, 'en', "Krasnopresnenskaya", 1 );
INSERT INTO String VALUES ( 2, 83, 'en', "Medvedkovo", 1 );
INSERT INTO String VALUES ( 2, 84, 'en', "Babushkinskaya", 1 );
INSERT INTO String VALUES ( 2, 85, 'en', "Sviblovo", 1 );
INSERT INTO String VALUES ( 2, 86, 'en', "Botanichesky Sad", 1 );
INSERT INTO String VALUES ( 2, 87, 'en', "VDNKh", 1 );
INSERT INTO String VALUES ( 2, 88, 'en', "Alexeyevskaya", 1 );
INSERT INTO String VALUES ( 2, 89, 'en', "Rizhskaya", 1 );
INSERT INTO String VALUES ( 2, 91, 'en', "Sukharevskaya", 1 );
INSERT INTO String VALUES ( 2, 92, 'en', "Turgenevskaya", 1 );
INSERT INTO String VALUES ( 2, 93, 'en', "Kitay-Gorod", 1 );
INSERT INTO String VALUES ( 2, 94, 'en', "Tretyakovskaya", 1 );
INSERT INTO String VALUES ( 2, 96, 'en', "Shabolovskaya", 1 );
INSERT INTO String VALUES ( 2, 97, 'en', "Leninsky Prospekt", 1 );
INSERT INTO String VALUES ( 2, 98, 'en', "Akademicheskaya", 1 );
INSERT INTO String VALUES ( 2, 99, 'en', "Profsoyuznaya", 1 );
INSERT INTO String VALUES ( 2, 100, 'en', "Noviye Cheryomushki", 1 );
INSERT INTO String VALUES ( 2, 101, 'en', "Kaluzhskaya", 1 );
INSERT INTO String VALUES ( 2, 102, 'en', "Belyayevo", 1 );
INSERT INTO String VALUES ( 2, 103, 'en', "Konkovo", 1 );
INSERT INTO String VALUES ( 2, 104, 'en', "Tyoplyi Stan", 1 );
INSERT INTO String VALUES ( 2, 105, 'en', "Yasenevo", 1 );
INSERT INTO String VALUES ( 2, 106, 'en', "Novoyasenevskaya", 1 );
INSERT INTO String VALUES ( 2, 107, 'en', "Planernaya", 1 );
INSERT INTO String VALUES ( 2, 108, 'en', "Skhodnenskaya", 1 );
INSERT INTO String VALUES ( 2, 109, 'en', "Tushinskaya", 1 );
INSERT INTO String VALUES ( 2, 110, 'en', "Shchukinskaya", 1 );
INSERT INTO String VALUES ( 2, 111, 'en', "Oktyabrskoye Pole", 1 );
INSERT INTO String VALUES ( 2, 112, 'en', "Polezhaevskaya", 1 );
INSERT INTO String VALUES ( 2, 113, 'en', "Begovaya", 1 );
INSERT INTO String VALUES ( 2, 114, 'en', "Ulitsa 1905 Goda", 1 );
INSERT INTO String VALUES ( 2, 115, 'en', "Barrikadnaya", 1 );
INSERT INTO String VALUES ( 2, 116, 'en', "Pushkinskaya", 1 );
INSERT INTO String VALUES ( 2, 117, 'en', "Kuznetsky Most", 1 );
INSERT INTO String VALUES ( 2, 120, 'en', "Proletarskaya", 1 );
INSERT INTO String VALUES ( 2, 121, 'en', "Volgogradsky Prospekt", 1 );
INSERT INTO String VALUES ( 2, 122, 'en', "Tekstilshchiki", 1 );
INSERT INTO String VALUES ( 2, 123, 'en', "Kuzminki", 1 );
INSERT INTO String VALUES ( 2, 124, 'en', "Ryazanskiy Prospekt", 1 );
INSERT INTO String VALUES ( 2, 125, 'en', "Vykhino", 1 );
INSERT INTO String VALUES ( 2, 126, 'en', "Novogireevo", 1 );
INSERT INTO String VALUES ( 2, 127, 'en', "Perovo", 1 );
INSERT INTO String VALUES ( 2, 128, 'en', "Shosse Entuziastov", 1 );
INSERT INTO String VALUES ( 2, 129, 'en', "Aviamotornaya", 1 );
INSERT INTO String VALUES ( 2, 130, 'en', "Ploshchad Ilicha", 1 );
INSERT INTO String VALUES ( 2, 131, 'en', "Marksistskaya", 1 );
INSERT INTO String VALUES ( 2, 133, 'en', "Altufyevo", 1 );
INSERT INTO String VALUES ( 2, 134, 'en', "Bibirevo", 1 );
INSERT INTO String VALUES ( 2, 135, 'en', "Otradnoye", 1 );
INSERT INTO String VALUES ( 2, 136, 'en', "Vladykino", 1 );
INSERT INTO String VALUES ( 2, 137, 'en', "Petrovsko-Razumovskaya", 1 );
INSERT INTO String VALUES ( 2, 138, 'en', "Timiryazevskaya", 1 );
INSERT INTO String VALUES ( 2, 139, 'en', "Dmitrovskaya", 1 );
INSERT INTO String VALUES ( 2, 140, 'en', "Savyolovskaya", 1 );
INSERT INTO String VALUES ( 2, 141, 'en', "Mendeleyevskaya", 1 );
INSERT INTO String VALUES ( 2, 142, 'en', "Tsvetnoy Bulvar", 1 );
INSERT INTO String VALUES ( 2, 143, 'en', "Chekhovskaya", 1 );
INSERT INTO String VALUES ( 2, 144, 'en', "Borovitskaya", 1 );
INSERT INTO String VALUES ( 2, 145, 'en', "Polyanka", 1 );
INSERT INTO String VALUES ( 2, 146, 'en', "Serpukhovskaya", 1 );
INSERT INTO String VALUES ( 2, 147, 'en', "Tulskaya", 1 );
INSERT INTO String VALUES ( 2, 148, 'en', "Nagatinskaya", 1 );
INSERT INTO String VALUES ( 2, 149, 'en', "Nagornaya", 1 );
INSERT INTO String VALUES ( 2, 150, 'en', "Nakhimovsky Prospekt", 1 );
INSERT INTO String VALUES ( 2, 151, 'en', "Sevastopolskaya", 1 );
INSERT INTO String VALUES ( 2, 152, 'en', "Chertanovskaya", 1 );
INSERT INTO String VALUES ( 2, 153, 'en', "Yuzhnaya", 1 );
INSERT INTO String VALUES ( 2, 154, 'en', "Prazhskaya", 1 );
INSERT INTO String VALUES ( 2, 155, 'en', "Ulitsa Akademika Yangelya", 1 );
INSERT INTO String VALUES ( 3, 155, 'en', "Ulitsa
Akademika Yangelya", 1 );
INSERT INTO String VALUES ( 2, 156, 'en', "Annino", 1 );
INSERT INTO String VALUES ( 2, 157, 'en', "Bulvar Dmitriya Donskogo", 1 );
INSERT INTO String VALUES ( 2, 181, 'en', "Maryina Roshcha", 1 );
INSERT INTO String VALUES ( 2, 182, 'en', "Dostoyevskaya", 1 );
INSERT INTO String VALUES ( 2, 158, 'en', "Trubnaya", 1 );
INSERT INTO String VALUES ( 2, 159, 'en', "Sretensky Bulvar", 1 );
INSERT INTO String VALUES ( 2, 160, 'en', "Chkalovskaya", 1 );
INSERT INTO String VALUES ( 2, 161, 'en', "Rimskaya", 1 );
INSERT INTO String VALUES ( 2, 162, 'en', "Krestyanskaya Zastava", 1 );
INSERT INTO String VALUES ( 2, 163, 'en', "Dubrovka", 1 );
INSERT INTO String VALUES ( 2, 164, 'en', "Kozhukhovskaya", 1 );
INSERT INTO String VALUES ( 2, 165, 'en', "Pechatniki", 1 );
INSERT INTO String VALUES ( 2, 166, 'en', "Volzhskaya", 1 );
INSERT INTO String VALUES ( 2, 167, 'en', "Lyublino", 1 );
INSERT INTO String VALUES ( 2, 168, 'en', "Bratislavskaya", 1 );
INSERT INTO String VALUES ( 2, 169, 'en', "Maryino", 1 );
INSERT INTO String VALUES ( 2, 171, 'en', "Varshavskaya", 1 );
INSERT INTO String VALUES ( 2, 172, 'en', "Kakhovskaya", 1 );
INSERT INTO String VALUES ( 2, 173, 'en', "Ulitsa Starokachalovskaya", 1 );
INSERT INTO String VALUES ( 2, 174, 'en', "Ulitsa Skobelevskaya", 1 );
INSERT INTO String VALUES ( 2, 175, 'en', "Bulvar Admirala Ushakova", 1 );
INSERT INTO String VALUES ( 2, 176, 'en', "Ulitsa Gorchakova", 1 );
INSERT INTO String VALUES ( 2, 177, 'en', "Buninskaya Alleya", 1 );
INSERT INTO String VALUES ( 0, 13, 'bel', "Minsk", 13 );
INSERT INTO String VALUES ( 0, 13, 'ru', "Minsk", 13 );
INSERT INTO String VALUES ( 0, 13, 'en', "Minsk", 13 );
INSERT INTO String VALUES ( 1, 1, 'bel', "Маскоўская лінія", 13 );
INSERT INTO String VALUES ( 1, 2, 'bel', "Аўтазаводская лінія", 13 );
INSERT INTO String VALUES ( 1, 1, 'ru', "Московская линия", 13 );
INSERT INTO String VALUES ( 1, 2, 'ru', "Автозаводская линия", 13 );
INSERT INTO String VALUES ( 1, 1, 'en', "Moskovskaya Line", 13 );
INSERT INTO String VALUES ( 1, 2, 'en', "Avtozavodskaya Line", 13 );
INSERT INTO String VALUES ( 2, 1, 'bel', "Уручча", 13 );
INSERT INTO String VALUES ( 2, 2, 'bel', "Барысаўскі тракт", 13 );
INSERT INTO String VALUES ( 2, 3, 'bel', "Усход", 13 );
INSERT INTO String VALUES ( 2, 4, 'bel', "Маскоўская", 13 );
INSERT INTO String VALUES ( 2, 5, 'bel', "Парк Чалюскінцаў", 13 );
INSERT INTO String VALUES ( 2, 6, 'bel', "Акадэмія навук", 13 );
INSERT INTO String VALUES ( 2, 7, 'bel', "Плошча Якуба Коласа", 13 );
INSERT INTO String VALUES ( 2, 8, 'bel', "Плошча Перамогі", 13 );
INSERT INTO String VALUES ( 2, 9, 'bel', "Кастрычніцкая", 13 );
INSERT INTO String VALUES ( 2, 10, 'bel', "Плошча Леніна", 13 );
INSERT INTO String VALUES ( 2, 11, 'bel', "Інстытут культуры", 13 );
INSERT INTO String VALUES ( 2, 12, 'bel', "Каменная Горка", 13 );
INSERT INTO String VALUES ( 2, 13, 'bel', "Кунцаўшчына", 13 );
INSERT INTO String VALUES ( 2, 14, 'bel', "Спартыўная", 13 );
INSERT INTO String VALUES ( 2, 15, 'bel', "Пушкінская", 13 );
INSERT INTO String VALUES ( 2, 16, 'bel', "Маладзёжная", 13 );
INSERT INTO String VALUES ( 2, 17, 'bel', "Фрунзенская", 13 );
INSERT INTO String VALUES ( 2, 18, 'bel', "Няміга", 13 );
INSERT INTO String VALUES ( 2, 19, 'bel', "Купалаўская", 13 );
INSERT INTO String VALUES ( 2, 20, 'bel', "Першамайская", 13 );
INSERT INTO String VALUES ( 2, 21, 'bel', "Пралетарская", 13 );
INSERT INTO String VALUES ( 2, 22, 'bel', "Трактарны завод", 13 );
INSERT INTO String VALUES ( 2, 23, 'bel', "Партызанская", 13 );
INSERT INTO String VALUES ( 2, 24, 'bel', "Аўтазаводская", 13 );
INSERT INTO String VALUES ( 2, 25, 'bel', "Магілёўская", 13 );
INSERT INTO String VALUES ( 2, 1, 'ru', "Уручье", 13 );
INSERT INTO String VALUES ( 2, 2, 'ru', "Борисовский тракт", 13 );
INSERT INTO String VALUES ( 2, 3, 'ru', "Восток", 13 );
INSERT INTO String VALUES ( 2, 4, 'ru', "Московская", 13 );
INSERT INTO String VALUES ( 2, 5, 'ru', "Парк Челюскинцев", 13 );
INSERT INTO String VALUES ( 2, 6, 'ru', "Академия наук", 13 );
INSERT INTO String VALUES ( 2, 7, 'ru', "Площадь Якуба Коласа", 13 );
INSERT INTO String VALUES ( 2, 8, 'ru', "Площадь Победы", 13 );
INSERT INTO String VALUES ( 2, 9, 'ru', "Октябрьская", 13 );
INSERT INTO String VALUES ( 2, 10, 'ru', "Площадь Ленина", 13 );
INSERT INTO String VALUES ( 2, 11, 'ru', "Институт культуры", 13 );
INSERT INTO String VALUES ( 2, 12, 'ru', "Каменная горка", 13 );
INSERT INTO String VALUES ( 2, 13, 'ru', "Кунцевщина", 13 );
INSERT INTO String VALUES ( 2, 14, 'ru', "Спортивная", 13 );
INSERT INTO String VALUES ( 2, 15, 'ru', "Пушкинская", 13 );
INSERT INTO String VALUES ( 2, 16, 'ru', "Молодёжная", 13 );
INSERT INTO String VALUES ( 2, 17, 'ru', "Фрунзенская", 13 );
INSERT INTO String VALUES ( 2, 18, 'ru', "Немига", 13 );
INSERT INTO String VALUES ( 2, 19, 'ru', "Купаловская", 13 );
INSERT INTO String VALUES ( 2, 20, 'ru', "Первомайская", 13 );
INSERT INTO String VALUES ( 2, 21, 'ru', "Пролетарская", 13 );
INSERT INTO String VALUES ( 2, 22, 'ru', "Тракторный завод", 13 );
INSERT INTO String VALUES ( 2, 23, 'ru', "Партизанская", 13 );
INSERT INTO String VALUES ( 2, 24, 'ru', "Автозаводская", 13 );
INSERT INTO String VALUES ( 2, 25, 'ru', "Могилёвская", 13 );
INSERT INTO String VALUES ( 2, 1, 'en', "Uruchye", 13 );
INSERT INTO String VALUES ( 2, 2, 'en', "Borisovsky Trakt", 13 );
INSERT INTO String VALUES ( 2, 3, 'en', "Vostok", 13 );
INSERT INTO String VALUES ( 2, 4, 'en', "Moskovskaya", 13 );
INSERT INTO String VALUES ( 2, 5, 'en', "Park Chelyuskintsev", 13 );
INSERT INTO String VALUES ( 2, 6, 'en', "Akademiya Nauk", 13 );
INSERT INTO String VALUES ( 2, 7, 'en', "Ploshchad Yakuba Kolasa", 13 );
INSERT INTO String VALUES ( 2, 8, 'en', "Ploshchad Pobedy", 13 );
INSERT INTO String VALUES ( 2, 9, 'en', "Oktyabrskaya", 13 );
INSERT INTO String VALUES ( 2, 10, 'en', "Ploshchad Lenina", 13 );
INSERT INTO String VALUES ( 2, 11, 'en', "Institut Kultury", 13 );
INSERT INTO String VALUES ( 2, 12, 'en', "Kamennaya Gorka", 13 );
INSERT INTO String VALUES ( 2, 13, 'en', "Kuntsevshchina", 13 );
INSERT INTO String VALUES ( 2, 14, 'en', "Sportivnaya", 13 );
INSERT INTO String VALUES ( 2, 15, 'en', "Pushkinskaya", 13 );
INSERT INTO String VALUES ( 2, 16, 'en', "Molodyozhnaya", 13 );
INSERT INTO String VALUES ( 2, 17, 'en', "Frunzenskaya", 13 );
INSERT INTO String VALUES ( 2, 18, 'en', "Nemiga", 13 );
INSERT INTO String VALUES ( 2, 19, 'en', "Kupalovskaya", 13 );
INSERT INTO String VALUES ( 2, 20, 'en', "Pervomaiskaya", 13 );
INSERT INTO String VALUES ( 2, 21, 'en', "Proletarskaya", 13 );
INSERT INTO String VALUES ( 2, 22, 'en', "Traktornyi Zavod", 13 );
INSERT INTO String VALUES ( 2, 23, 'en', "Patizanskaya", 13 );
INSERT INTO String VALUES ( 2, 24, 'en', "Avtozavodskaya", 13 );
INSERT INTO String VALUES ( 2, 25, 'en', "Mogilevskaya", 13 );
INSERT INTO String VALUES ( 0, 2, 'ru', "SaintPetersburg", 2 );
INSERT INTO String VALUES ( 0, 2, 'en', "SaintPetersburg", 2 );
INSERT INTO String VALUES ( 1, 1, 'ru', "Кировско-Выборгская", 2 );
INSERT INTO String VALUES ( 1, 2, 'ru', "Московско-Петроградская", 2 );
INSERT INTO String VALUES ( 1, 3, 'ru', "Невско-Василеостровская", 2 );
INSERT INTO String VALUES ( 1, 4, 'ru', "Правобережная", 2 );
INSERT INTO String VALUES ( 1, 5, 'ru', "Фрунзенско-Приморская", 2 );
INSERT INTO String VALUES ( 1, 1, 'en', "Kirovsko-Vyborgskaya", 2 );
INSERT INTO String VALUES ( 1, 2, 'en', "Moskovsko-Petrogradskaya", 2 );
INSERT INTO String VALUES ( 1, 3, 'en', "Nevsko-Vasileostrovskaya", 2 );
INSERT INTO String VALUES ( 1, 4, 'en', "Pravoberezhnaya", 2 );
INSERT INTO String VALUES ( 1, 5, 'en', "Frunzensko-Primorskaya", 2 );
INSERT INTO String VALUES ( 2, 1, 'ru', "Девяткино", 2 );
INSERT INTO String VALUES ( 2, 2, 'ru', "Гражданский проспект", 2 );
INSERT INTO String VALUES ( 2, 3, 'ru', "Академическая", 2 );
INSERT INTO String VALUES ( 2, 4, 'ru', "Политехническая", 2 );
INSERT INTO String VALUES ( 2, 5, 'ru', "Площадь Мужества", 2 );
INSERT INTO String VALUES ( 2, 6, 'ru', "Лесная", 2 );
INSERT INTO String VALUES ( 2, 7, 'ru', "Выборгская", 2 );
INSERT INTO String VALUES ( 2, 8, 'ru', "Площадь Ленина", 2 );
INSERT INTO String VALUES ( 2, 9, 'ru', "Чернышевская", 2 );
INSERT INTO String VALUES ( 2, 10, 'ru', "Площадь Восстания", 2 );
INSERT INTO String VALUES ( 2, 11, 'ru', "Владимирская", 2 );
INSERT INTO String VALUES ( 2, 12, 'ru', "Пушкинская", 2 );
INSERT INTO String VALUES ( 2, 13, 'ru', "Технологический институт - 1", 2 );
INSERT INTO String VALUES ( 2, 14, 'ru', "Балтийская", 2 );
INSERT INTO String VALUES ( 2, 15, 'ru', "Нарвская", 2 );
INSERT INTO String VALUES ( 2, 16, 'ru', "Кировский завод", 2 );
INSERT INTO String VALUES ( 2, 17, 'ru', "Автово", 2 );
INSERT INTO String VALUES ( 2, 18, 'ru', "Ленинский проспект", 2 );
INSERT INTO String VALUES ( 2, 19, 'ru', "Проспект Ветеранов", 2 );
INSERT INTO String VALUES ( 2, 20, 'ru', "Парнас", 2 );
INSERT INTO String VALUES ( 2, 21, 'ru', "Проспект Просвещения", 2 );
INSERT INTO String VALUES ( 2, 22, 'ru', "Озерки", 2 );
INSERT INTO String VALUES ( 2, 23, 'ru', "Удельная", 2 );
INSERT INTO String VALUES ( 2, 24, 'ru', "Пионерская", 2 );
INSERT INTO String VALUES ( 2, 25, 'ru', "Чёрная речка", 2 );
INSERT INTO String VALUES ( 2, 26, 'ru', "Петроградская", 2 );
INSERT INTO String VALUES ( 2, 27, 'ru', "Горьковская", 2 );
INSERT INTO String VALUES ( 2, 28, 'ru', "Невский проспект", 2 );
INSERT INTO String VALUES ( 2, 29, 'ru', "Сенная площадь", 2 );
INSERT INTO String VALUES ( 2, 30, 'ru', "Технологический институт - 2", 2 );
INSERT INTO String VALUES ( 2, 31, 'ru', "Фрунзенская", 2 );
INSERT INTO String VALUES ( 2, 32, 'ru', "Московские ворота", 2 );
INSERT INTO String VALUES ( 2, 33, 'ru', "Электросила", 2 );
INSERT INTO String VALUES ( 2, 34, 'ru', "Парк Победы", 2 );
INSERT INTO String VALUES ( 2, 35, 'ru', "Московская", 2 );
INSERT INTO String VALUES ( 2, 36, 'ru', "Звёздная", 2 );
INSERT INTO String VALUES ( 2, 37, 'ru', "Купчино", 2 );
INSERT INTO String VALUES ( 2, 38, 'ru', "Приморская", 2 );
INSERT INTO String VALUES ( 2, 39, 'ru', "Василеостровская", 2 );
INSERT INTO String VALUES ( 2, 40, 'ru', "Гостиный двор", 2 );
INSERT INTO String VALUES ( 2, 41, 'ru', "Маяковская", 2 );
INSERT INTO String VALUES ( 2, 42, 'ru', "Площадь Александра Невского - 1", 2 );
INSERT INTO String VALUES ( 2, 43, 'ru', "Елизаровская", 2 );
INSERT INTO String VALUES ( 2, 44, 'ru', "Ломоносовская", 2 );
INSERT INTO String VALUES ( 2, 45, 'ru', "Пролетарская", 2 );
INSERT INTO String VALUES ( 2, 46, 'ru', "Обухово", 2 );
INSERT INTO String VALUES ( 2, 47, 'ru', "Рыбацкое", 2 );
INSERT INTO String VALUES ( 2, 48, 'ru', "Спасская", 2 );
INSERT INTO String VALUES ( 2, 49, 'ru', "Достоевская", 2 );
INSERT INTO String VALUES ( 2, 50, 'ru', "Лиговский проспект", 2 );
INSERT INTO String VALUES ( 3, 50, 'ru', "Лиговский
проспект", 2 );
INSERT INTO String VALUES ( 2, 51, 'ru', "Площадь Александра Невского - 2", 2 );
INSERT INTO String VALUES ( 2, 52, 'ru', "Новочеркасская", 2 );
INSERT INTO String VALUES ( 2, 53, 'ru', "Ладожская", 2 );
INSERT INTO String VALUES ( 2, 54, 'ru', "Проспект Большевиков", 2 );
INSERT INTO String VALUES ( 2, 55, 'ru', "Улица Дыбенко", 2 );
INSERT INTO String VALUES ( 2, 56, 'ru', "Комендантский проспект", 2 );
INSERT INTO String VALUES ( 2, 57, 'ru', "Старая Деревня", 2 );
INSERT INTO String VALUES ( 2, 58, 'ru', "Крестовский остров", 2 );
INSERT INTO String VALUES ( 2, 59, 'ru', "Чкаловская", 2 );
INSERT INTO String VALUES ( 2, 60, 'ru', "Спортивная", 2 );
INSERT INTO String VALUES ( 2, 61, 'ru', "Садовая", 2 );
INSERT INTO String VALUES ( 2, 62, 'ru', "Звенигородская", 2 );
INSERT INTO String VALUES ( 2, 63, 'ru', "Волковская", 2 );
INSERT INTO String VALUES ( 2, 1, 'en', "Devyatkino", 2 );
INSERT INTO String VALUES ( 2, 2, 'en', "Grazhdansky Prospekt", 2 );
INSERT INTO String VALUES ( 2, 3, 'en', "Akademicheskaya", 2 );
INSERT INTO String VALUES ( 2, 4, 'en', "Politekhnicheskaya", 2 );
INSERT INTO String VALUES ( 2, 5, 'en', "Ploschad Muzhestva", 2 );
INSERT INTO String VALUES ( 2, 6, 'en', "Lesnaya", 2 );
INSERT INTO String VALUES ( 2, 7, 'en', "Vyborgskaya", 2 );
INSERT INTO String VALUES ( 2, 8, 'en', "Ploshchad Lenina", 2 );
INSERT INTO String VALUES ( 2, 9, 'en', "Chernyshevskaya", 2 );
INSERT INTO String VALUES ( 2, 10, 'en', "Ploschad Vosstania", 2 );
INSERT INTO String VALUES ( 2, 11, 'en', "Vladimirskaya", 2 );
INSERT INTO String VALUES ( 2, 12, 'en', "Pushkinskaya", 2 );
INSERT INTO String VALUES ( 2, 13, 'en', "Tekhnologichesky Institut - 1", 2 );
INSERT INTO String VALUES ( 2, 14, 'en', "Baltiyskaya", 2 );
INSERT INTO String VALUES ( 2, 15, 'en', "Narvskaya", 2 );
INSERT INTO String VALUES ( 2, 16, 'en', "Kirovsky Zavod", 2 );
INSERT INTO String VALUES ( 2, 17, 'en', "Avtovo", 2 );
INSERT INTO String VALUES ( 2, 18, 'en', "Leninsky Prospekt", 2 );
INSERT INTO String VALUES ( 2, 19, 'en', "Prospekt Veteranov", 2 );
INSERT INTO String VALUES ( 2, 20, 'en', "Parnas", 2 );
INSERT INTO String VALUES ( 2, 21, 'en', "Prospekt Prosvescheniya", 2 );
INSERT INTO String VALUES ( 2, 22, 'en', "Ozerki", 2 );
INSERT INTO String VALUES ( 2, 23, 'en', "Udelnaya", 2 );
INSERT INTO String VALUES ( 2, 24, 'en', "Pionerskaya", 2 );
INSERT INTO String VALUES ( 2, 25, 'en', "Chornaya Rechka", 2 );
INSERT INTO String VALUES ( 2, 26, 'en', "Petrogradskaya", 2 );
INSERT INTO String VALUES ( 2, 27, 'en', "Gorkovskaya", 2 );
INSERT INTO String VALUES ( 2, 28, 'en', "Nevsky Prospekt", 2 );
INSERT INTO String VALUES ( 2, 29, 'en', "Sennaya Ploshchad", 2 );
INSERT INTO String VALUES ( 2, 30, 'en', "Tekhnologichesky Institut - 2", 2 );
INSERT INTO String VALUES ( 2, 31, 'en', "Frunzenskaya", 2 );
INSERT INTO String VALUES ( 2, 32, 'en', "Moskovskiye Vorota", 2 );
INSERT INTO String VALUES ( 2, 33, 'en', "Elektrosila", 2 );
INSERT INTO String VALUES ( 2, 34, 'en', "Park Pobedy", 2 );
INSERT INTO String VALUES ( 2, 35, 'en', "Moskovskaya", 2 );
INSERT INTO String VALUES ( 2, 36, 'en', "Zvyozdnaya", 2 );
INSERT INTO String VALUES ( 2, 37, 'en', "Kupchino", 2 );
INSERT INTO String VALUES ( 2, 38, 'en', "Primorskaya", 2 );
INSERT INTO String VALUES ( 2, 39, 'en', "Vasileostrovskaya", 2 );
INSERT INTO String VALUES ( 2, 40, 'en', "Gostiny Dvor", 2 );
INSERT INTO String VALUES ( 2, 41, 'en', "Mayakovskaya", 2 );
INSERT INTO String VALUES ( 2, 42, 'en', "Ploshchad Alexandra Nevskogo - 1", 2 );
INSERT INTO String VALUES ( 2, 43, 'en', "Yelizarovskaya", 2 );
INSERT INTO String VALUES ( 2, 44, 'en', "Lomonosovskaya", 2 );
INSERT INTO String VALUES ( 2, 45, 'en', "Proletarskaya", 2 );
INSERT INTO String VALUES ( 2, 46, 'en', "Obukhovo", 2 );
INSERT INTO String VALUES ( 2, 47, 'en', "Rybatskoe", 2 );
INSERT INTO String VALUES ( 2, 48, 'en', "Spasskaya", 2 );
INSERT INTO String VALUES ( 2, 49, 'en', "Dostoyevskaya", 2 );
INSERT INTO String VALUES ( 2, 50, 'en', "Ligovsky Prospekt", 2 );
INSERT INTO String VALUES ( 2, 51, 'en', "Ploshchad Alexandra Nevskogo - 2", 2 );
INSERT INTO String VALUES ( 2, 52, 'en', "Novocherkasskaya", 2 );
INSERT INTO String VALUES ( 2, 53, 'en', "Ladozhskaya", 2 );
INSERT INTO String VALUES ( 2, 54, 'en', "Prospekt Bolshevikov", 2 );
INSERT INTO String VALUES ( 2, 55, 'en', "Ulitsa Dybenko", 2 );
INSERT INTO String VALUES ( 2, 56, 'en', "Komendatsky Prospekt", 2 );
INSERT INTO String VALUES ( 2, 57, 'en', "Staraya Derevnya", 2 );
INSERT INTO String VALUES ( 2, 58, 'en', "Krestovsky Ostrov", 2 );
INSERT INTO String VALUES ( 2, 59, 'en', "Chkalovskaya", 2 );
INSERT INTO String VALUES ( 2, 60, 'en', "Sportivnaya", 2 );
INSERT INTO String VALUES ( 2, 61, 'en', "Sadovaya", 2 );
INSERT INTO String VALUES ( 2, 62, 'en', "Zvenigorodskaya", 2 );
INSERT INTO String VALUES ( 2, 63, 'en', "Volkovskaya", 2 );
INSERT INTO String VALUES ( 0, 8, 'ukr', "Kiev", 8 );
INSERT INTO String VALUES ( 0, 8, 'ru', "Kiev", 8 );
INSERT INTO String VALUES ( 0, 8, 'en', "Kiev", 8 );
INSERT INTO String VALUES ( 1, 1, 'ukr', "Святошинсько-Броварська", 8 );
INSERT INTO String VALUES ( 1, 2, 'ukr', "Куренівсько-Червоноармійська", 8 );
INSERT INTO String VALUES ( 1, 3, 'ukr', "Сирецько-Печерська", 8 );
INSERT INTO String VALUES ( 1, 1, 'ru', "Святошинско-Броварская", 8 );
INSERT INTO String VALUES ( 1, 2, 'ru', "Куренёвско-Красноармейская", 8 );
INSERT INTO String VALUES ( 1, 3, 'ru', "Сырецко-Печерская", 8 );
INSERT INTO String VALUES ( 1, 1, 'en', "Sviatoshynsko-Brovarska", 8 );
INSERT INTO String VALUES ( 1, 2, 'en', "Kurenivsko-Chervonoarmiyska", 8 );
INSERT INTO String VALUES ( 1, 3, 'en', "Syretsko-Pecherska", 8 );
INSERT INTO String VALUES ( 2, 1, 'ukr', "Академмістечко", 8 );
INSERT INTO String VALUES ( 2, 2, 'ukr', "Житомирська", 8 );
INSERT INTO String VALUES ( 2, 3, 'ukr', "Святошин", 8 );
INSERT INTO String VALUES ( 2, 4, 'ukr', "Нивки", 8 );
INSERT INTO String VALUES ( 2, 5, 'ukr', "Берестейська", 8 );
INSERT INTO String VALUES ( 2, 6, 'ukr', "Шулявська", 8 );
INSERT INTO String VALUES ( 2, 7, 'ukr', "Політехнічний інститут", 8 );
INSERT INTO String VALUES ( 2, 8, 'ukr', "Вокзальна", 8 );
INSERT INTO String VALUES ( 2, 9, 'ukr', "Університет", 8 );
INSERT INTO String VALUES ( 2, 10, 'ukr', "Театральна", 8 );
INSERT INTO String VALUES ( 2, 11, 'ukr', "Хрещатик", 8 );
INSERT INTO String VALUES ( 2, 12, 'ukr', "Арсенальна", 8 );
INSERT INTO String VALUES ( 2, 13, 'ukr', "Дніпро", 8 );
INSERT INTO String VALUES ( 2, 14, 'ukr', "Гідропарк", 8 );
INSERT INTO String VALUES ( 2, 15, 'ukr', "Лівобережна", 8 );
INSERT INTO String VALUES ( 2, 16, 'ukr', "Дарниця", 8 );
INSERT INTO String VALUES ( 2, 17, 'ukr', "Чернігівська", 8 );
INSERT INTO String VALUES ( 2, 18, 'ukr', "Лісова", 8 );
INSERT INTO String VALUES ( 2, 19, 'ukr', "Героїв Дніпра", 8 );
INSERT INTO String VALUES ( 2, 20, 'ukr', "Мінська", 8 );
INSERT INTO String VALUES ( 2, 21, 'ukr', "Оболонь", 8 );
INSERT INTO String VALUES ( 2, 22, 'ukr', "Петрівка", 8 );
INSERT INTO String VALUES ( 2, 23, 'ukr', "Тараса Шевченка", 8 );
INSERT INTO String VALUES ( 2, 24, 'ukr', "Контрактова площа", 8 );
INSERT INTO String VALUES ( 2, 25, 'ukr', "Поштова площа", 8 );
INSERT INTO String VALUES ( 2, 26, 'ukr', "Майдан Незалежності", 8 );
INSERT INTO String VALUES ( 2, 27, 'ukr', "Площа Льва Толстого", 8 );
INSERT INTO String VALUES ( 2, 28, 'ukr', "Республіканський стадіон", 8 );
INSERT INTO String VALUES ( 2, 29, 'ukr', "Палац «Україна»", 8 );
INSERT INTO String VALUES ( 2, 30, 'ukr', "Либідська", 8 );
INSERT INTO String VALUES ( 2, 31, 'ukr', "Сирець", 8 );
INSERT INTO String VALUES ( 2, 32, 'ukr', "Дорогожичі", 8 );
INSERT INTO String VALUES ( 2, 33, 'ukr', "Лук'янівська", 8 );
INSERT INTO String VALUES ( 2, 34, 'ukr', "Золоті ворота", 8 );
INSERT INTO String VALUES ( 2, 35, 'ukr', "Палац спорту", 8 );
INSERT INTO String VALUES ( 2, 36, 'ukr', "Кловська", 8 );
INSERT INTO String VALUES ( 2, 37, 'ukr', "Печерська", 8 );
INSERT INTO String VALUES ( 2, 38, 'ukr', "Дружби народів", 8 );
INSERT INTO String VALUES ( 2, 39, 'ukr', "Видубичі", 8 );
INSERT INTO String VALUES ( 2, 40, 'ukr', "Славутич", 8 );
INSERT INTO String VALUES ( 2, 41, 'ukr', "Осокорки", 8 );
INSERT INTO String VALUES ( 2, 42, 'ukr', "Позняки", 8 );
INSERT INTO String VALUES ( 2, 43, 'ukr', "Харківська", 8 );
INSERT INTO String VALUES ( 2, 44, 'ukr', "Вирлиця", 8 );
INSERT INTO String VALUES ( 2, 45, 'ukr', "Бориспільська", 8 );
INSERT INTO String VALUES ( 2, 46, 'ukr', "Червоний хутір", 8 );
INSERT INTO String VALUES ( 2, 1, 'ru', "Академгородок", 8 );
INSERT INTO String VALUES ( 2, 2, 'ru', "Житомирская", 8 );
INSERT INTO String VALUES ( 2, 3, 'ru', "Святошин", 8 );
INSERT INTO String VALUES ( 2, 4, 'ru', "Нивки", 8 );
INSERT INTO String VALUES ( 2, 5, 'ru', "Берестейская", 8 );
INSERT INTO String VALUES ( 2, 6, 'ru', "Шулявская", 8 );
INSERT INTO String VALUES ( 2, 7, 'ru', "Политехнический институт", 8 );
INSERT INTO String VALUES ( 2, 8, 'ru', "Вокзальная", 8 );
INSERT INTO String VALUES ( 2, 9, 'ru', "Университет", 8 );
INSERT INTO String VALUES ( 2, 10, 'ru', "Театральная", 8 );
INSERT INTO String VALUES ( 2, 11, 'ru', "Крещатик", 8 );
INSERT INTO String VALUES ( 2, 12, 'ru', "Арсенальная", 8 );
INSERT INTO String VALUES ( 2, 13, 'ru', "Днепр", 8 );
INSERT INTO String VALUES ( 2, 14, 'ru', "Гидропарк", 8 );
INSERT INTO String VALUES ( 2, 15, 'ru', "Левобережная", 8 );
INSERT INTO String VALUES ( 2, 16, 'ru', "Дарница", 8 );
INSERT INTO String VALUES ( 2, 17, 'ru', "Черниговская", 8 );
INSERT INTO String VALUES ( 2, 18, 'ru', "Лесная", 8 );
INSERT INTO String VALUES ( 2, 19, 'ru', "Героев Днепра", 8 );
INSERT INTO String VALUES ( 2, 20, 'ru', "Минская", 8 );
INSERT INTO String VALUES ( 2, 21, 'ru', "Оболонь", 8 );
INSERT INTO String VALUES ( 2, 22, 'ru', "Петровка", 8 );
INSERT INTO String VALUES ( 2, 23, 'ru', "Тараса Шевченко", 8 );
INSERT INTO String VALUES ( 2, 24, 'ru', "Контрактовая площадь", 8 );
INSERT INTO String VALUES ( 2, 25, 'ru', "Почтовая площадь", 8 );
INSERT INTO String VALUES ( 2, 26, 'ru', "Площадь Независимости", 8 );
INSERT INTO String VALUES ( 2, 27, 'ru', "Площадь Льва Толстого", 8 );
INSERT INTO String VALUES ( 2, 28, 'ru', "Республиканский стадион", 8 );
INSERT INTO String VALUES ( 2, 29, 'ru', "Дворец «Украина»", 8 );
INSERT INTO String VALUES ( 2, 30, 'ru', "Лыбедская", 8 );
INSERT INTO String VALUES ( 2, 31, 'ru', "Сырец", 8 );
INSERT INTO String VALUES ( 2, 32, 'ru', "Дорогожичи", 8 );
INSERT INTO String VALUES ( 2, 33, 'ru', "Лукьяновская", 8 );
INSERT INTO String VALUES ( 2, 34, 'ru', "Золотые ворота", 8 );
INSERT INTO String VALUES ( 2, 35, 'ru', "Дворец спорта", 8 );
INSERT INTO String VALUES ( 2, 36, 'ru', "Кловская", 8 );
INSERT INTO String VALUES ( 2, 37, 'ru', "Печерская", 8 );
INSERT INTO String VALUES ( 2, 38, 'ru', "Дружбы Народов", 8 );
INSERT INTO String VALUES ( 2, 39, 'ru', "Выдубичи", 8 );
INSERT INTO String VALUES ( 2, 40, 'ru', "Славутич", 8 );
INSERT INTO String VALUES ( 2, 41, 'ru', "Осокорки", 8 );
INSERT INTO String VALUES ( 2, 42, 'ru', "Позняки", 8 );
INSERT INTO String VALUES ( 2, 43, 'ru', "Харьковская", 8 );
INSERT INTO String VALUES ( 2, 44, 'ru', "Вырлица", 8 );
INSERT INTO String VALUES ( 2, 45, 'ru', "Бориспольская", 8 );
INSERT INTO String VALUES ( 2, 46, 'ru', "Красный хутор", 8 );
INSERT INTO String VALUES ( 2, 1, 'en', "Akademmistechko", 8 );
INSERT INTO String VALUES ( 2, 2, 'en', "Zhytomyrska", 8 );
INSERT INTO String VALUES ( 2, 3, 'en', "Sviatoshyn", 8 );
INSERT INTO String VALUES ( 2, 4, 'en', "Nyvky", 8 );
INSERT INTO String VALUES ( 2, 5, 'en', "Beresteiska", 8 );
INSERT INTO String VALUES ( 2, 6, 'en', "Shuliavska", 8 );
INSERT INTO String VALUES ( 2, 7, 'en', "Politekhnichnyi Instytut", 8 );
INSERT INTO String VALUES ( 2, 8, 'en', "Vokzalna", 8 );
INSERT INTO String VALUES ( 2, 9, 'en', "Universytet", 8 );
INSERT INTO String VALUES ( 2, 10, 'en', "Teatralna", 8 );
INSERT INTO String VALUES ( 2, 11, 'en', "Khreshchatyk", 8 );
INSERT INTO String VALUES ( 2, 12, 'en', "Arsenalna", 8 );
INSERT INTO String VALUES ( 2, 13, 'en', "Dnipro", 8 );
INSERT INTO String VALUES ( 2, 14, 'en', "Hidropark", 8 );
INSERT INTO String VALUES ( 2, 15, 'en', "Livoberezhna", 8 );
INSERT INTO String VALUES ( 2, 16, 'en', "Darnytsia", 8 );
INSERT INTO String VALUES ( 2, 17, 'en', "Chernihivska", 8 );
INSERT INTO String VALUES ( 2, 18, 'en', "Lisova", 8 );
INSERT INTO String VALUES ( 2, 19, 'en', "Heroiv Dnipra", 8 );
INSERT INTO String VALUES ( 2, 20, 'en', "Minska", 8 );
INSERT INTO String VALUES ( 2, 21, 'en', "Obolon", 8 );
INSERT INTO String VALUES ( 2, 22, 'en', "Petrivka", 8 );
INSERT INTO String VALUES ( 2, 23, 'en', "Tarasa Shevchenka", 8 );
INSERT INTO String VALUES ( 2, 24, 'en', "Kontraktova Ploshcha", 8 );
INSERT INTO String VALUES ( 2, 25, 'en', "Poshtova Ploshcha", 8 );
INSERT INTO String VALUES ( 2, 26, 'en', "Maidan Nezalezhnosti", 8 );
INSERT INTO String VALUES ( 2, 27, 'en', "Ploshcha Lva Tolstoho", 8 );
INSERT INTO String VALUES ( 2, 28, 'en', "Respublikansky Stadion", 8 );
INSERT INTO String VALUES ( 2, 29, 'en', "Palats Ukrayina", 8 );
INSERT INTO String VALUES ( 2, 30, 'en', "Lybidska", 8 );
INSERT INTO String VALUES ( 2, 31, 'en', "Syrets", 8 );
INSERT INTO String VALUES ( 2, 32, 'en', "Dorohozhychi", 8 );
INSERT INTO String VALUES ( 2, 33, 'en', "Lukianivska", 8 );
INSERT INTO String VALUES ( 2, 34, 'en', "Zoloti Vorota", 8 );
INSERT INTO String VALUES ( 2, 35, 'en', "Palats Sportu", 8 );
INSERT INTO String VALUES ( 2, 36, 'en', "Klovska", 8 );
INSERT INTO String VALUES ( 2, 37, 'en', "Pecherska", 8 );
INSERT INTO String VALUES ( 2, 38, 'en', "Druzhby Narodiv", 8 );
INSERT INTO String VALUES ( 2, 39, 'en', "Vydubychi", 8 );
INSERT INTO String VALUES ( 2, 40, 'en', "Slavutych", 8 );
INSERT INTO String VALUES ( 2, 41, 'en', "Osokorky", 8 );
INSERT INTO String VALUES ( 2, 42, 'en', "Pozniaky", 8 );
INSERT INTO String VALUES ( 2, 43, 'en', "Kharkivska", 8 );
INSERT INTO String VALUES ( 2, 44, 'en', "Vyrlytsia", 8 );
INSERT INTO String VALUES ( 2, 45, 'en', "Boryspilska", 8 );
INSERT INTO String VALUES ( 2, 46, 'en', "Chervony Khutir", 8 );
INSERT INTO String VALUES ( 0, 9, 'ukr', "Kharkiv", 9 );
INSERT INTO String VALUES ( 0, 9, 'ru', "Kharkiv", 9 );
INSERT INTO String VALUES ( 0, 9, 'en', "Kharkiv", 9 );
INSERT INTO String VALUES ( 1, 1, 'ukr', "Холодногірсько-заводська", 9 );
INSERT INTO String VALUES ( 1, 2, 'ukr', "Салтівська", 9 );
INSERT INTO String VALUES ( 1, 3, 'ukr', "Олексіївська", 9 );
INSERT INTO String VALUES ( 1, 1, 'ru', "Холодногорско-Заводская", 9 );
INSERT INTO String VALUES ( 1, 2, 'ru', "Салтовская", 9 );
INSERT INTO String VALUES ( 1, 3, 'ru', "Алексеевская", 9 );
INSERT INTO String VALUES ( 1, 1, 'en', "Kholodnohirsko–Zavodska", 9 );
INSERT INTO String VALUES ( 1, 2, 'en', "Saltivska", 9 );
INSERT INTO String VALUES ( 1, 3, 'en', "Oleksiivska", 9 );
INSERT INTO String VALUES ( 2, 1, 'ukr', "Холодна гора", 9 );
INSERT INTO String VALUES ( 2, 2, 'ukr', "Південний вокзал", 9 );
INSERT INTO String VALUES ( 2, 3, 'ukr', "Центральний ринок", 9 );
INSERT INTO String VALUES ( 2, 4, 'ukr', "Радянська", 9 );
INSERT INTO String VALUES ( 2, 5, 'ukr', "Проспект Гагаріна", 9 );
INSERT INTO String VALUES ( 2, 6, 'ukr', "Спортивна", 9 );
INSERT INTO String VALUES ( 2, 7, 'ukr', "Завод імені Малишева", 9 );
INSERT INTO String VALUES ( 2, 8, 'ukr', "Московський проспект", 9 );
INSERT INTO String VALUES ( 2, 9, 'ukr', "Імені маршала Жукова", 9 );
INSERT INTO String VALUES ( 2, 10, 'ukr', "Радянської армії", 9 );
INSERT INTO String VALUES ( 2, 11, 'ukr', "Імені О.С. Масельського", 9 );
INSERT INTO String VALUES ( 2, 12, 'ukr', "Тракторний завод", 9 );
INSERT INTO String VALUES ( 2, 13, 'ukr', "Пролетарська", 9 );
INSERT INTO String VALUES ( 2, 14, 'ukr', "Героїв праці", 9 );
INSERT INTO String VALUES ( 2, 15, 'ukr', "Студентська", 9 );
INSERT INTO String VALUES ( 2, 16, 'ukr', "Академіка Павлова", 9 );
INSERT INTO String VALUES ( 2, 17, 'ukr', "Академіка Барабашова", 9 );
INSERT INTO String VALUES ( 2, 18, 'ukr', "Київська", 9 );
INSERT INTO String VALUES ( 2, 19, 'ukr', "Пушкінська", 9 );
INSERT INTO String VALUES ( 2, 20, 'ukr', "Університет", 9 );
INSERT INTO String VALUES ( 2, 21, 'ukr', "Історичний музей", 9 );
INSERT INTO String VALUES ( 2, 22, 'ukr', "23 Серпня", 9 );
INSERT INTO String VALUES ( 2, 23, 'ukr', "Ботанічний сад", 9 );
INSERT INTO String VALUES ( 2, 24, 'ukr', "Наукова", 9 );
INSERT INTO String VALUES ( 2, 25, 'ukr', "Держпром", 9 );
INSERT INTO String VALUES ( 2, 26, 'ukr', "Архітектора Бекетова", 9 );
INSERT INTO String VALUES ( 2, 27, 'ukr', "Площа Повстання", 9 );
INSERT INTO String VALUES ( 2, 28, 'ukr', "Метробудівників імені Ващенка", 9 );
INSERT INTO String VALUES ( 2, 1, 'ru', "Холодная гора", 9 );
INSERT INTO String VALUES ( 2, 2, 'ru', "Южный вокзал", 9 );
INSERT INTO String VALUES ( 2, 3, 'ru', "Центральный рынок", 9 );
INSERT INTO String VALUES ( 2, 4, 'ru', "Советская", 9 );
INSERT INTO String VALUES ( 2, 5, 'ru', "Проспект Гагарина", 9 );
INSERT INTO String VALUES ( 2, 6, 'ru', "Спортивная", 9 );
INSERT INTO String VALUES ( 2, 7, 'ru', "Завод имени Малышева", 9 );
INSERT INTO String VALUES ( 2, 8, 'ru', "Московский проспект", 9 );
INSERT INTO String VALUES ( 2, 9, 'ru', "Имени маршала Жукова", 9 );
INSERT INTO String VALUES ( 2, 10, 'ru', "Советской армии", 9 );
INSERT INTO String VALUES ( 2, 11, 'ru', "Имени А.С. Масельского", 9 );
INSERT INTO String VALUES ( 2, 12, 'ru', "Тракторный завод", 9 );
INSERT INTO String VALUES ( 2, 13, 'ru', "Пролетарская", 9 );
INSERT INTO String VALUES ( 2, 14, 'ru', "Героев труда", 9 );
INSERT INTO String VALUES ( 2, 15, 'ru', "Студенческая", 9 );
INSERT INTO String VALUES ( 2, 16, 'ru', "Академика Павлова", 9 );
INSERT INTO String VALUES ( 2, 17, 'ru', "Академика Барабашова", 9 );
INSERT INTO String VALUES ( 2, 18, 'ru', "Киевская", 9 );
INSERT INTO String VALUES ( 2, 19, 'ru', "Пушкинская", 9 );
INSERT INTO String VALUES ( 2, 20, 'ru', "Университет", 9 );
INSERT INTO String VALUES ( 2, 21, 'ru', "Исторический музей", 9 );
INSERT INTO String VALUES ( 2, 22, 'ru', "23 Августа", 9 );
INSERT INTO String VALUES ( 2, 23, 'ru', "Ботанический сад", 9 );
INSERT INTO String VALUES ( 2, 24, 'ru', "Научная", 9 );
INSERT INTO String VALUES ( 2, 25, 'ru', "Госпром", 9 );
INSERT INTO String VALUES ( 2, 26, 'ru', "Архитектора Бекетова", 9 );
INSERT INTO String VALUES ( 2, 27, 'ru', "Площадь Восстания", 9 );
INSERT INTO String VALUES ( 2, 28, 'ru', "Метростроителей имени Ващенко", 9 );
INSERT INTO String VALUES ( 2, 1, 'en', "Kholodna Hora", 9 );
INSERT INTO String VALUES ( 2, 2, 'en', "Pivdennyi Vokzal", 9 );
INSERT INTO String VALUES ( 2, 3, 'en', "Tsentralny Rynok", 9 );
INSERT INTO String VALUES ( 2, 4, 'en', "Radianska", 9 );
INSERT INTO String VALUES ( 2, 5, 'en', "Prospekt Haharina", 9 );
INSERT INTO String VALUES ( 2, 6, 'en', "Sportyvna", 9 );
INSERT INTO String VALUES ( 2, 7, 'en', "Zavod Imeni Malysheva", 9 );
INSERT INTO String VALUES ( 2, 8, 'en', "Moskovsky Prospekt", 9 );
INSERT INTO String VALUES ( 2, 9, 'en', "Imeni Marshala Zhukova", 9 );
INSERT INTO String VALUES ( 2, 10, 'en', "Radianskoyi Armii", 9 );
INSERT INTO String VALUES ( 2, 11, 'en', "Imeni O.S. Maselskoho", 9 );
INSERT INTO String VALUES ( 2, 12, 'en', "Traktorny Zavod", 9 );
INSERT INTO String VALUES ( 2, 13, 'en', "Proletraska", 9 );
INSERT INTO String VALUES ( 2, 14, 'en', "Heroiv Truda", 9 );
INSERT INTO String VALUES ( 2, 15, 'en', "Studentska", 9 );
INSERT INTO String VALUES ( 2, 16, 'en', "Akademika Pavlova", 9 );
INSERT INTO String VALUES ( 2, 17, 'en', "Akademika Barabashova", 9 );
INSERT INTO String VALUES ( 2, 18, 'en', "Kyivska", 9 );
INSERT INTO String VALUES ( 2, 19, 'en', "Pushkinska", 9 );
INSERT INTO String VALUES ( 2, 20, 'en', "Universytet", 9 );
INSERT INTO String VALUES ( 2, 21, 'en', "Istorychniy Muzei", 9 );
INSERT INTO String VALUES ( 2, 22, 'en', "23 Avgusta", 9 );
INSERT INTO String VALUES ( 2, 23, 'en', "Botanicheskiy Sad", 9 );
INSERT INTO String VALUES ( 2, 24, 'en', "Nauchnaya", 9 );
INSERT INTO String VALUES ( 2, 25, 'en', "Gosprom", 9 );
INSERT INTO String VALUES ( 2, 26, 'en', "Arkhitektora Beketova", 9 );
INSERT INTO String VALUES ( 2, 27, 'en', "Ploshchad Vosstaniya", 9 );
INSERT INTO String VALUES ( 2, 28, 'en', "Metrostroitelei Imeni Vashchenko", 9 );

